@@ -24,6 +24,7 @@
 u_long id = 1235598744;
 u_long options = BE_NONE;
 
+#define USE_THREAD
 
 static char *file = NULL;
 static SF_INFO	sfi;
@@ -130,7 +131,9 @@ run(Context_t *ctx)
   /* si lecture finie: on recommence ou on exit */
   if (frames < 1) {
     if (loop) {
+#ifdef DEBUG
       printf("[i] sndfile: restarting stream '%s'\n", file);
+#endif
       /* rewind */
       if (-1 == sf_seek(sf, 0, SEEK_SET))
 	xerror("sf_seek\n");
