@@ -20,7 +20,7 @@
 #include "context.h"
 
 u_long id = 1253393977;
-u_long options = BE_NONE; /* synchronized input -- as with sndfile */
+u_long options = BEQ_THREAD;
 
 #define INSIZE	256
 #define FACT	0.40
@@ -53,7 +53,7 @@ static inline float
 Rndq(void)
 {
   u_long  a, b;
-  int  n = read(urandfd, (void *)&a, sizeof(u_long));
+  read(urandfd, (void *)&a, sizeof(u_long));
   b = (~0);
   return (((float)a) / ((float)b));
 }
@@ -77,7 +77,7 @@ static inline u_long
 Randq(void)
 {
   u_long  a;
-  int  n = read(urandfd, (void *)&a, sizeof(u_long));
+  read(urandfd, (void *)&a, sizeof(u_long));
   return a;
 }
 
@@ -102,15 +102,18 @@ Rand(u_long range)
   return (Rand(ma - mi + 1) + mi);
   } <-- unused here */
 
+
 void
 create(Context_t *ctx)
 {
   int  i;
+
   urandfd = open(DEVICE, O_RDONLY);
   if (urandfd == -1)
     xerror("Unable to open `%s'\n", DEVICE);
 
   ctx->input = Input_new(INSIZE);
+
   /* initialize twip */
   for (i = 0; i < CHANNELS; i++) {
     frequency[i] = RangeRnd(MIN_FREQUENCY, MAX_FREQUENCY);
@@ -120,62 +123,76 @@ create(Context_t *ctx)
   }
 }
 
+
 void
 destroy(Context_t *ctx)
 {
   Input_delete(ctx->input);
-  if (urandfd != -1) {
+  if (urandfd != -1)
     close(urandfd);
-    urandfd = -1;
-  }
 }
 
-void
-run(Context_t *ctx)
+
+void *
+jthread(void *args)
 {
-  int  j;
-  for (j = 0; j < INSIZE; j++) {
-    StereoSample  smp;
-    int  i;
-    for (i = 0; i < CHANNELS; i++) {
-      float  fr, newfr, sc, sp, t, y;
-      /* get twip values */
-      fr = frequency[i];
-      sc = scale[i];
-      sp = speed[i];
-      t = xtime[i];
-      /* compute sample */
-      smp.sample[i] = sinf(t * 2 * M_PI) * FACT;
-      /* modify speed */
-      if (Rand(SAMPLES_PER_SECOND / 100) == nearbyintf(MAX_FREQUENCY / 200)) {
-        y = RangeRnd(-1, 1) / SAMPLES_PER_SECOND;
-        sp += y;
-        if ((sp > MAX_SPEED) || (sp < MIN_SPEED))
-          sp -= (y * 2);
+  Context_t *ctx = (Context_t *)args;
+
+  while (ctx->running) {
+    int  j;
+
+    for (j = 0; j < INSIZE; j++) {
+      StereoSample  smp;
+      int  i;
+
+      for (i = 0; i < CHANNELS; i++) {
+	float  fr, newfr, sc, sp, t, y;
+
+	/* get twip values */
+	fr = frequency[i];
+	sc = scale[i];
+	sp = speed[i];
+	t = xtime[i];
+
+	/* compute sample */
+	smp.sample[i] = sinf(t * 2 * M_PI) * FACT;
+
+	/* modify speed */
+	if (Rand(SAMPLES_PER_SECOND / 100) == nearbyintf(MAX_FREQUENCY / 200)) {
+	  y = RangeRnd(-1, 1) / SAMPLES_PER_SECOND;
+	  sp += y;
+	  if ((sp > MAX_SPEED) || (sp < MIN_SPEED))
+	    sp -= (y * 2);
+	}
+
+	/* modify frequency and/or scale */
+	while (1) {
+	  newfr = powf(2, sc * sp / SAMPLES_PER_SECOND / 12) * fr;
+	  if (newfr < MIN_FREQUENCY)
+	    sc = Rndq();
+	  else if (newfr > MAX_FREQUENCY)
+	    sc = -Rndq();
+	  else if (Rand(SAMPLES_PER_SECOND / 10) == nearbyintf(MAX_FREQUENCY / 20))
+	    sc = RangeRnd(-1, 1);
+	  else
+	    break;
+	}
+
+	/* update twip */
+	frequency[i] = newfr;
+	scale[i] = sc;
+	speed[i] = sp;
+	t += (newfr / SAMPLES_PER_SECOND);
+	xtime[i] = (t - floorf(t));
       }
-      /* modify frequency and/or scale */
-      while (1) {
-        newfr = powf(2, sc * sp / SAMPLES_PER_SECOND / 12) * fr;
-        if (newfr < MIN_FREQUENCY)
-          sc = Rndq();
-        else if (newfr > MAX_FREQUENCY)
-          sc = -Rndq();
-        else if (Rand(SAMPLES_PER_SECOND / 10) == nearbyintf(MAX_FREQUENCY / 20))
-          sc = RangeRnd(-1, 1);
-        else
-          break;
-      }
-      /* update twip */
-      frequency[i] = newfr;
-      scale[i] = sc;
-      speed[i] = sp;
-      t += (newfr / SAMPLES_PER_SECOND);
-      xtime[i] = (t - floorf(t));
+      ctx->input->data[A_LEFT ][j] = smp.sample[CHANNEL_LEFT ];
+      ctx->input->data[A_RIGHT][j] = smp.sample[CHANNEL_RIGHT];
     }
-    ctx->input->data[A_LEFT ][j] = smp.sample[CHANNEL_LEFT ];
-    ctx->input->data[A_RIGHT][j] = smp.sample[CHANNEL_RIGHT];
+
+    /* buffer written, build FFTs, etc. */
+    Input_set(ctx->input, A_STEREO);
   }
-  /* buffer written, build FFTs, etc. */
-  Input_set(ctx->input, A_STEREO);
+
   /* that's all, folks ! */
+  return NULL;
 }
