@@ -28,12 +28,13 @@ u_long mode = OVERLAY;
 static int line = 0;
 static int prevline = 0;
 static Pixel_t *linebuf = NULL;
+extern int webcams;
 
 
 void
 create(__attribute__ ((unused)) Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
   else {
     line = MAXY;
@@ -70,13 +71,13 @@ run(Context_t *ctx)
   Pixel_t *src = NULL;
   Pixel_t *dst = passive_buffer(ctx)->buffer;
 
-  if (!ctx->has_cam)
+  if (!webcams)
     return;
 
-  pthread_mutex_lock(&ctx->cam_mtx);
-  src = ctx->buffers[CAM_IN_BUFFER]->buffer;
+  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+  src = ctx->cam_save[ctx->cam][0]->buffer;
   blitline_buf(src, dst);
-  pthread_mutex_unlock(&ctx->cam_mtx);
+  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 
   if (line)
     line--;
