@@ -40,12 +40,13 @@ u_long mode = OVERLAY;
 #define PLANES 8
 
 static Buffer8_t *nervous = NULL;
+extern int webcams;
 
 
 void
-create(Context_t *ctx)
+create(__attribute__ ((unused)) Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
   else
     if (PLANES > CAM_SAVE) {
@@ -76,13 +77,13 @@ run(Context_t *ctx)
   Buffer8_t *src = NULL;
   Buffer8_t *dst = passive_buffer(ctx);
 
-  if (!ctx->has_cam)
+  if (!webcams)
     return;
 
-  pthread_mutex_lock(&ctx->cam_mtx);
-  src = ctx->cam_save[nervous->buffer[r]];
+  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+  src = ctx->cam_save[ctx->cam][nervous->buffer[r]];
   Buffer8_copy(src, dst);
-  pthread_mutex_unlock(&ctx->cam_mtx);
+  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 
   if (++r == BUFFSIZE)
     r = 0;
