@@ -36,12 +36,13 @@ u_long mode = OVERLAY;
 #define MAGIC_THRESHOLD 40
 
 static Buffer8_t *diff = NULL;
+extern int webcams;
 
 
 void
-create(Context_t *ctx)
+create(__attribute__ ((unused)) Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
   else
     diff = Buffer8_new();
@@ -58,7 +59,7 @@ delete(__attribute__ ((unused)) Context_t *ctx)
 void
 on_switch_on(Context_t *ctx)
 {
-  ctx->ref_taken = 0;
+  ctx->ref_taken[ctx->cam] = 0;
 }
 
 
@@ -109,21 +110,21 @@ run(Context_t *ctx)
   Pixel_t *dst;
   uint16_t x, y;
 
-  if (!ctx->has_cam)
+  if (!webcams)
     return;
 
-  pthread_mutex_lock(&ctx->cam_mtx);
-  src1 = ctx->buffers[CAM_IN_BUFFER];
-  src2 = ctx->buffers[CAM_REF_BUFFER];
+  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+  src1 = ctx->cam_save[ctx->cam][0];
+  src2 = ctx->cam_ref[ctx->cam];
   Buffer8_substract_y(src1, src2, MAGIC_THRESHOLD, diff);
 
   d = diff->buffer;
 
+  dst = passive_buffer(ctx)->buffer;
   dst += WIDTH * sizeof(Pixel_t);
   d += WIDTH * sizeof(Pixel_t);
-  src = ctx->buffers[CAM_REF_BUFFER]->buffer + (WIDTH * sizeof(Pixel_t));
+  src = ctx->cam_ref[ctx->cam]->buffer + (WIDTH * sizeof(Pixel_t));
 
-  dst = passive_buffer(ctx)->buffer;
   for (y = 1; y < MAXY; y++) {
     for (x = 0; x < WIDTH; x++) {
       if (*d)
@@ -136,7 +137,7 @@ run(Context_t *ctx)
       dst++;
     }
   }
-  pthread_mutex_unlock(&ctx->cam_mtx);
+  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
 
 
