@@ -34,15 +34,15 @@ char desc[] = "QuarkTV plugin from the EffecTV project";
 u_long mode = OVERLAY;
 
 #define MIN_FRAMES 11
-#define USE_MUTEX  0
 
 static Buffer8_t *qtv = NULL;
+extern int webcams;
 
 
 void
-create(Context_t *ctx)
+create(__attribute__ ((unused)) Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
   else
     if (MIN_FRAMES > CAM_SAVE) {
@@ -72,23 +72,19 @@ run(Context_t *ctx)
   uint64_t i;
   Pixel_t *dst;
 
-  if (!ctx->has_cam)
+  if (!webcams)
     return;
 
   dst = passive_buffer(ctx)->buffer;
 
-#if USE_MUTEX
-  pthread_mutex_lock(&ctx->cam_mtx);
-#endif
+  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
 
   for (i = 0; i < BUFFSIZE; i++, dst++) {
     const Pixel_t rnd = qtv->buffer[i];
-    *dst = ctx->cam_save[rnd]->buffer[i];
+    *dst = ctx->cam_save[ctx->cam][rnd]->buffer[i];
   }
 
-#if USE_MUTEX
-  pthread_mutex_unlock(&ctx->cam_mtx);
-#endif
+  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
 
 
