@@ -41,12 +41,13 @@ u_long mode = OVERLAY;
 static Buffer8_t *planes[PLANES];
 static Pixel_t *planetable[PLANES];
 static int plane = 0;
+extern int webcams;
 
 
 void
-create(Context_t *ctx)
+create(__attribute__ ((unused)) Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
   else
     if (PLANES > CAM_SAVE) {
@@ -81,15 +82,15 @@ run(Context_t *ctx)
   uint8_t cf;
   Pixel_t *dst;
   
-  if (!ctx->has_cam)
+  if (!webcams)
     return;
 
   dst = passive_buffer(ctx)->buffer;
   
-  pthread_mutex_lock(&ctx->cam_mtx);
+  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   for (i = 0; i < BUFFSIZE; i++)
-    planetable[plane][i] = (ctx->buffers[CAM_IN_BUFFER]->buffer[i] & STRIDE_MASK) >> STRIDE_SHIFT;
-  pthread_mutex_unlock(&ctx->cam_mtx);
+    planetable[plane][i] = (ctx->cam_save[ctx->cam][0]->buffer[i] & STRIDE_MASK) >> STRIDE_SHIFT;
+  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 
   cf = plane & (STRIDE-1);
   for (i = 0; i < BUFFSIZE; i++) {
