@@ -96,17 +96,15 @@ destroy(__attribute__ ((unused)) Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  char volume;
+  u_char volume = 0;
 
   if (ctx->input == NULL)
     return;
 
-  volume = (char)(Input_get_volume(ctx->input) * 10);
+  volume = (u_char)(Input_get_volume(ctx->input) * 10);
 
   if (volume >= NB_FCT)
     volume = NB_FCT-1;
-  else if (volume < 0)
-    volume = 0;
   
   VectorField_run(vf, ctx, volume);
 }
