@@ -23,11 +23,13 @@ u_long id = 1172430309;
 u_long options = BE_GFX|BEQ_PICTURE|BEQ_BYPASS;
 char desc[] = "Webcam plugin";
 
+extern int webcams;
+
 
 void
-create(Context_t *ctx)
+create(__attribute__ ((unused)) Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
 }
 
@@ -35,10 +37,10 @@ create(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  if (!ctx->has_cam)
+  if (!webcams)
     options |= BEQ_DISABLED;
 
-  pthread_mutex_lock(&ctx->cam_mtx);
-  Buffer8_copy(ctx->buffers[ctx->cam], passive_buffer(ctx));
-  pthread_mutex_unlock(&ctx->cam_mtx);
+  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+  Buffer8_copy(ctx->cam_save[ctx->cam][0], passive_buffer(ctx));
+  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
