@@ -20,13 +20,14 @@
 #include <SDL/SDL.h>
 #include "ttf.h"
 
-#define NO_MOUSE_CURSOR
+/* #define NO_MOUSE_CURSOR */
 
 u_long id = 1327695029;
 u_long options = BE_NONE;
 
 
 static SDL_Surface *surface;
+static Plugin_t *glcube = NULL;
 
 
 static void
@@ -53,8 +54,12 @@ SDL_get_event(Context_t *ctx)
       break;
 			
     case SDL_MOUSEMOTION:
+      // printf("motion.state: %d\n", evt.motion.state);
+      //printf("left: %d\n", SDL_BUTTON_LEFT);
+      //printf("right: %d\n", SDL_BUTTON_RIGHT);
+
       switch (evt.motion.state) {
-	/* TODO un switch pour le mouse drag/dtrop mode */
+	/* TODO un switch pour le mouse drag/drop mode */
       case SDL_BUTTON_LEFT:
 #ifdef WITH_GL
 	ctx->params3d.gl_xe = evt.motion.x;
@@ -65,6 +70,12 @@ SDL_get_event(Context_t *ctx)
 	ctx->params3d.ye = evt.motion.y;
 	Params3d_rotate(&ctx->params3d);
 #endif
+	// printf("left button motion @ %d %d\n",  evt.motion.x, evt.motion.y);
+	break;
+
+      case SDL_BUTTON_RIGHT+SDL_BUTTON_LEFT: /* <- WTF ? */
+	// printf("right button motion @ %d %d\n",  evt.motion.x, evt.motion.y);
+	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
 	break;
 
       default:
@@ -84,11 +95,17 @@ SDL_get_event(Context_t *ctx)
 	ctx->params3d.ys = evt.motion.y;
 #endif
 	break;
+
+      case SDL_BUTTON_RIGHT:
+	// printf("button down @ %d %d\n",  evt.motion.x, evt.motion.y);
+	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
+	break;
 	
       case SDL_BUTTON_WHEELUP:
 #ifdef WITH_GL /* TODO switch GL/not-GL */
 	if (ctx->params3d.gl_fov > 1)
 	  ctx->params3d.gl_fov--;
+	//printf("FOV: %f\n", ctx->params3d.gl_fov);
 #else
 	ctx->params3d.scale_factor /= 0.9;
 	/* printf("scale: %d\n", ctx->params3d->scale_factor); */
@@ -98,6 +115,7 @@ SDL_get_event(Context_t *ctx)
       case SDL_BUTTON_WHEELDOWN:
 #ifdef WITH_GL /* TODO switch GL/not-GL */
 	ctx->params3d.gl_fov++;
+	//printf("FOV: %f\n", ctx->params3d.gl_fov);
 #else
 	if (ctx->params3d.scale_factor > 11)
 	  ctx->params3d.scale_factor *= 0.9;
@@ -183,7 +201,7 @@ tex_point(const float x, const float y)
 void
 test_gl3(__attribute__ ((unused)) Context_t *ctx)
 {
-  Context_make_GL_texture(ctx, ACTIVE_BUFFER);
+  Context_make_GL_RGBA_texture(ctx, ACTIVE_BUFFER);
 
   //  glBindTexture(GL_TEXTURE_2D, ctx->textures[ACTIVE_BUFFER]);
 
@@ -217,15 +235,18 @@ void
 run(Context_t *ctx)
 {
   if (!ctx->gl_done) {
-    reshape(WIDTH, HEIGHT);
-    test_gl3(ctx);
+    if (ctx->force_cube && (NULL != glcube))
+      glcube->run(ctx);
+    else {
+      reshape(WIDTH, HEIGHT);
+      test_gl3(ctx);
+    }
   }
 
   if (ctx->osd_mode != OSD_NONE) {
-    glPushMatrix();
+    glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
     osd(ctx);
-    glPopMatrix();
     /* TODO merge with SDL code
     if (ctx->random_mode != BR_NONE)
       osd_random_mode_elapsed(ctx);
@@ -233,7 +254,6 @@ run(Context_t *ctx)
   }
 
   SDL_get_event(ctx);
-  // glFlush(); // needed ?
   SDL_GL_SwapBuffers();
 }
 
@@ -309,6 +329,15 @@ create(__attribute__ ((unused)) Context_t *ctx)
 {
   char *window_title;
 
+  /* Find default output plugin for OpenGL: GLCube */
+  /* FIXME hardcoded */
+  glcube = Plugins_find(1328382269);
+  if (NULL != glcube) {
+    printf("[i] glcube found @%p\n", glcube);
+    if (NULL != glcube->create)
+      glcube->create(ctx);
+  }
+
   /* Information about the current video settings. */
   const SDL_VideoInfo* info = NULL;
 
