@@ -75,10 +75,6 @@ set_cmap(Context_t *ctx)
 static inline void
 SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
 {
-  //u_long k = 0;
-  // Pixel_t *cptr = NULL;
-  //  RGBA_t *cptr = NULL;
-  //const Uint32 *buf;
   const RGBA_t *src;
 
   Buffer8_flip_v(active_buffer(ctx));
@@ -109,7 +105,11 @@ SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
   if (NULL == sws_context)
     xerror("sws_getContext\n");
 
+#if LIBSWSCALE_VERSION_MAJOR == 2
   ret = sws_scale(sws_context, (const uint8_t * const *)bufp_src, srcstride, 0, HEIGHT, dstbufp_src, dststride);
+#else
+  ret = sws_scale(sws_context, (uint8_t **)bufp_src, srcstride, 0, HEIGHT, dstbufp_src, dststride);
+#endif
   if (ret < 0)
     xerror("sws_scale\n");
 #endif
@@ -148,6 +148,11 @@ SDL_get_event(Context_t *ctx)
 	Params3d_rotate(&ctx->params3d);
 	break;
 
+      case SDL_BUTTON_RIGHT+SDL_BUTTON_LEFT: /* <- WTF ? */
+	// printf("right button motion @ %d %d\n",  evt.motion.x, evt.motion.y);
+	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
+	break;
+
       default:
 	break;
       }
@@ -160,6 +165,11 @@ SDL_get_event(Context_t *ctx)
 	ctx->params3d.xs = evt.motion.x;
 	ctx->params3d.ys = evt.motion.y;
 	break;
+
+      case SDL_BUTTON_RIGHT:
+	// printf("button down @ %d %d\n",  evt.motion.x, evt.motion.y);
+	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
+	break;
 	
       case SDL_BUTTON_WHEELUP:
 	ctx->params3d.scale_factor /= 0.9;
