@@ -17,14 +17,11 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "SDL.h"
+#include "biniou.h"
 #include "pictures.h"
 #include "colormaps.h"
+#include "ttf.h"
 
-#define FONT "/usr/share/fonts/truetype/freefont/FreeMono.ttf"
-
-static TTF_Font *font = NULL;
-#define PTSIZE     14
 
 #ifndef FIXED
 extern u_short out_width, out_height;
@@ -33,28 +30,8 @@ extern u_short out_width, out_height;
 #define out_height HEIGHT
 #endif
 
-static char enabled = 1;
+char enabled = 1;
 
-void
-ttf_init()
-{
-  /* Initialize the TTF library */
-  if (!TTF_WasInit())
-    if (TTF_Init() < 0)
-      xerror("Couldn't initialize TTF: %s\n", SDL_GetError());
-	
-  /* Open the font file with the requested point size */
-  font = TTF_OpenFont(FONT, PTSIZE);
-  if (font == NULL) {
-    printf("[!] %s, OSD is disabled.\n", SDL_GetError());
-    enabled = 0;
-  } else {
-    TTF_SetFontStyle(font, TTF_STYLE_NORMAL);
-    /* TTF_SetFontStyle(font, TTF_STYLE_BOLD); */
-  }
-}
-
-#define OSD_BUFFLEN 512
 #define BORDER      10
 #define ARROW       "->"
 
@@ -65,70 +42,6 @@ reset(char *buff)
 }
 
 
-static SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };
-static SDL_Color black = { 0, 0, 0, 0 };
-static SDL_Color red   = { 0xFF, 0, 0, 0 };
-
-
-u_short
-osd_print(const u_short x, u_short y,
-	  const u_char rev_x, const u_char rev_y,
-	  const u_char mode, const int disabled, const char *fmt, ...)
-{
-  char str[OSD_BUFFLEN+1];
-  va_list ap;
-  SDL_Surface *text = NULL;
-  SDL_Rect    dstrect;
-  SDL_Color   fg_color;
-
-  memset((void *)str, '\0', OSD_BUFFLEN*sizeof(char));
-  assert(fmt != NULL);
-  va_start(ap, fmt);
-  vsprintf(str, fmt, ap); /* TODO vsnprintf */
-  va_end(ap);
-
-  fg_color = (disabled) ? red : white;
-
-  text = ((mode == 1) || (mode == 2)) ? TTF_RenderText_Blended(font, str, black)
-    : TTF_RenderText_Shaded(font, str, fg_color, black);
-
-  if (text != NULL) {
-    if (mode == 3) {
-      dstrect.x = (rev_x) ? (out_width - x - text->w) : x;
-      dstrect.y = (rev_y) ? (out_height - y - text->h) : y;
-      dstrect.w = text->w;
-      dstrect.h = text->h;
-      SDL_BlitSurface(text, NULL, drv.sc, &dstrect);
-      SDL_FreeSurface(text);
-    } else {
-      int dx, dy;
-      
-      dstrect.w = text->w;
-      dstrect.h = text->h;
-      for (dx = -2; dx <= 2; dx ++) {
-	for (dy = -2; dy <= 2; dy ++) {
-	  dstrect.x = (rev_x) ? (out_width - x - text->w) : x;
-	  dstrect.y = (rev_y) ? (out_height - y - text->h) : y;
-	  dstrect.x += dx;
-	  dstrect.y += dy;
-	  SDL_BlitSurface(text, NULL, drv.sc, &dstrect);
-	}
-      }
-      SDL_FreeSurface(text);
-
-      text = TTF_RenderText_Blended(font, str, fg_color);
-      dstrect.x = (rev_x) ? (out_width - x - text->w) : x;
-      dstrect.y = (rev_y) ? (out_height - y - text->h) : y;
-      SDL_BlitSurface(text, NULL, drv.sc, &dstrect);
-      SDL_FreeSurface(text);
-    }
-    y += TTF_FontLineSkip(font) - 1; /* FIXME why -1 ?? --oliv3 */
-  }
-
-  return y;
-}
-
-
 static void
 osd_info(const Context_t *ctx) {
   char buff[OSD_BUFFLEN+1];
@@ -168,9 +81,21 @@ osd_info(const Context_t *ctx) {
   dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Sequence: %s",
 	   (cur_seq->name != NULL) ? cur_seq->name : "(none)");
 
-  /* Display current bankset:bank:sequence_name */
-  dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Bank: %d-%d",
-		    ctx->sm->cur_bankset+1, ctx->bank+1);
+  /* Display current bankset:bank */
+  switch (ctx->bank_mode) {
+  case SEQUENCES:
+    dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Sequences bank: %d-%d",
+		      ctx->bankset[SEQUENCES]+1, ctx->bank[SEQUENCES]+1);
+    break;
+  case COLORMAPS:
+    dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Colormaps bank: %d-%d",
+		      ctx->bankset[COLORMAPS]+1, ctx->bank[COLORMAPS]+1);
+    break;
+  case PICTURES:
+    dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Pictures bank: %d-%d",
+		      ctx->bankset[PICTURES]+1, ctx->bank[PICTURES]+1);
+    break;
+  }
 
   /* Display colormap and picture (if any) */
   assert(colormaps != NULL);
@@ -255,19 +180,22 @@ osd_sequence(const Context_t *ctx)
 }
 
 
+extern u_short fontlineskip;
+
+
 static void
 osd_plugins(const Context_t *ctx)
 {
 #define SHOW 5 /* number of plugins to display before/after the current plugin */
   short n;
   short start;
-  u_short dst_y = 2*SHOW*TTF_FontLineSkip(font) - 2*SHOW;
+  u_short dst_y = 2*SHOW*fontlineskip - 2*SHOW;
 
   start = plugins->selected_idx - SHOW;
   while (start < 0)
     start += plugins->size;
 
-  for (n = 0; (n <= 2*SHOW+1) && (n < plugins->size); ) {
+  for (n = 0; (n < 2*SHOW+1) && (n < plugins->size); ) {
     const char *arrow;
     char in_sequence;
     char *name;
@@ -280,8 +208,9 @@ osd_plugins(const Context_t *ctx)
 
     name = Plugin_dname(plugin);
     (void)osd_print(BORDER, dst_y, 0, 1, ctx->osd_mode, disabled, "%02d %s %c %s", start, arrow, in_sequence, name);
+    //dst_y = osd_print(BORDER, dst_y, 0, 1, ctx->osd_mode, disabled, "%02d %s %c %s", start, arrow, in_sequence, name);
     xfree(name);
-    dst_y -= TTF_FontLineSkip(font) - 1;
+    dst_y -= fontlineskip - 1;
     n++;
 
     start++;
@@ -291,28 +220,11 @@ osd_plugins(const Context_t *ctx)
 }
 
 
-void
-osd_random_mode_elapsed(const Context_t *ctx)
-{
-  float pct = Alarm_elapsed_pct(ctx->a_random);
-  u_char color = 255; /* TODO colormap->max */
-  u_short height = (u_short)((1.0 - pct) * out_height);
-  SDL_Rect r;
-  
-  r.x = out_width-PB_WIDTH;
-  r.y = out_height-height;
-  r.w = PB_WIDTH;
-  r.h = height;
-
-  SDL_FillRect(drv.sc, &r, color); 
-}
-
-
 static void
 osd_plugin_desc(const Context_t *ctx)
 {
   char *dsc = NULL;
-  int skip = TTF_FontLineSkip(font) - 1;
+  int skip = fontlineskip - 1;
 
   if (NULL == plugins->selected->desc)
     dsc = "NO DESCRIPTION";
@@ -341,12 +253,3 @@ osd(const Context_t *ctx) {
   if (ctx->osd_mode > OSD_MINI)
     osd_plugin_desc(ctx);
 }
-
-
-void
-ttf_quit()
-{
-  if (NULL != font)
-    TTF_CloseFont(font);
-  TTF_Quit();
-}
