@@ -22,7 +22,7 @@
 #include "pnglite.h"
 
 
-#define PROTOCOL     '7'
+#define PROTOCOL     '8'
 #define MAX_PROTOCOL PROTOCOL
 
 char proto = PROTOCOL;
@@ -40,10 +40,6 @@ char proto = PROTOCOL;
 u_long id = 1216486988;
 u_long options = BE_NONE;
 
-/* erlang port plugin */
-#define IN_FD      3
-#define OUT_FD     4
-
 #define EDEBUG 1
 
 /* TODO: when we do not USE_FILE,
@@ -51,8 +47,10 @@ u_long options = BE_NONE;
 #define USE_FILE 0
 FILE *in = NULL, *out = NULL;
 
+#ifdef WITH_WEBCAM
 static uint32_t png_size;
 static GByteArray *png_bin = NULL;
+#endif
 
 extern void v1(const Context_t *);
 extern void v2(const Context_t *);
@@ -61,6 +59,7 @@ extern void v4(const Context_t *);
 extern void v5(const Context_t *);
 extern void v6(const Context_t *);
 extern void v7(const Context_t *);
+extern void v8(const Context_t *);
 
 
 uint32_t last_colormap;
@@ -179,21 +178,6 @@ read_exact(u_char *buf, const size_t len)
 }
 
 
-ssize_t
-write_exact(const u_char *buf, const ssize_t len)
-{
-  ssize_t i, wrote = 0;
-
-  do {
-    if ((i = write(OUT_FD, buf+wrote, len-wrote)) <= 0)
-      return i;
-    wrote += i;
-  } while (wrote < len);
-
-  return len;
-}
-
-
 static void
 _info(const char *fmt, ...)
 {
@@ -216,7 +200,6 @@ info(const char *fmt, ...)
   char buf[BUFLEN+1];
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
-  int ret;
   u_char val;
   uint32_t len;
   va_list ap;
@@ -234,21 +217,16 @@ info(const char *fmt, ...)
   /* send packet size */
   total = sizeof(uint32_t)+sizeof(u_char)+len*sizeof(char);
   total2 = htonl(total);
-  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
+  write_uint32(&total2);
 
   /* protocol version */
   proto2 = htonl(proto);
-  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
+  write_uint32(&proto2);
 
   val = INFO_CHAR;
-  ret = write_exact(&val, sizeof(u_char));
+  write_uint8(&val);
 
-  ret = write_exact((const u_char *)&buf, len*sizeof(char));
-
-  /* XXX hack to make gcc happy
-   * variable ‘ret’ set but not used [-Werror=unused-but-set-variable]
-   */
-  ret++;
+  write_binary((uint8_t *)&buf, len);
 #endif /* EDEBUG */
 }
 
@@ -315,6 +293,7 @@ create_or_skip_sequence(Context_t *ctx, const uint32_t _id, u_char *buff)
 }
 
 
+#ifdef WITH_WEBCAM
 static void
 send_ack(__attribute__ ((unused)) Context_t *ctx, const u_char type, const u_char ack)
 {
@@ -322,24 +301,18 @@ send_ack(__attribute__ ((unused)) Context_t *ctx, const u_char type, const u_cha
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
   u_char buff[ACKLEN] = {type, 'A', 'c', 'k', ack};
-  int ret;
 
   /* send packet size */
   total = sizeof(uint32_t)+ACKLEN*sizeof(u_char);
   total2 = htonl(total);
-  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
+  write_uint32(&total2);
 
   /* protocol version */
   proto2 = htonl(proto);
-  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
+  write_uint32(&proto2);
 
   /* webcam */
-  ret = write_exact(buff, ACKLEN*sizeof(u_char));
-
-  /* XXX hack to make gcc happy
-   * variable ‘ret’ set but not used [-Werror=unused-but-set-variable]
-   */
-  ret++;
+  write_binary(buff, ACKLEN);
 }
 
 
@@ -385,10 +358,10 @@ send_webcam(Context_t *ctx)
     u_char *data;
 
     png_size = 0;
-    pthread_mutex_lock(&ctx->cam_mtx);
-    src = ctx->buffers[CAM_IN_BUFFER];
+    pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+    src = ctx->cam_save[ctx->cam][0];
     Buffer8_copy(src, cam);
-    pthread_mutex_unlock(&ctx->cam_mtx);
+    pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
     Buffer8_flip_v(cam);
     data = cam->buffer;
     ret = png_set_data(&png, WIDTH, HEIGHT, 8, PNG_GREYSCALE, data);
@@ -402,39 +375,40 @@ send_webcam(Context_t *ctx)
   total = sizeof(uint32_t)+sizeof(u_char)+2*sizeof(uint16_t)
     + png_size*sizeof(u_char);
   total2 = htonl(total);
-  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
+  write_uint32(&total2);
 
   /* protocol version */
   proto2 = htonl(proto);
-  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
+  write_uint32(&proto2);
 
   /* webcam */
   val = WEBCAM_CHAR;
-  ret = write_exact(&val, sizeof(u_char));
+  write_uint8(&val);
 
   /* image width, height */
   width2 = htons(WIDTH);
   height2 = htons(HEIGHT);
-  ret = write_exact((const u_char *)&width2, sizeof(uint16_t));
-  ret = write_exact((const u_char *)&height2, sizeof(uint16_t));
+  write_uint16(&width2);
+  write_uint16(&height2);
 
   /* webcam PNG */
-  ret = write_exact(png_bin->data, png_size*sizeof(u_char));
+  write_binary(png_bin->data, png_size);
   g_byte_array_free(png_bin, TRUE);
 
   /* Ack */
   send_ack(ctx, WEBCAM_CHAR, 1);
 }
 
+
 static void
 send_biniou(Context_t *ctx)
 {
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
   uint16_t width2, height2;
-  int ret;
   u_char val;
   png_t png;
+  int ret;
 
   /* prepare PNG binary */
   png_bin = g_byte_array_new();
@@ -458,29 +432,30 @@ send_biniou(Context_t *ctx)
   total = sizeof(uint32_t)+sizeof(u_char)+2*sizeof(uint16_t)
     + png_size*sizeof(u_char);
   total2 = htonl(total);
-  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
+  write_uint32(&total2);
 
   /* protocol version */
   proto2 = htonl(proto);
-  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
+  write_uint32(&proto2);
 
   /* biniou */
   val = BINIOU_CHAR;
-  ret = write_exact(&val, sizeof(u_char));
+  write_uint8(&val);
 
   /* image width, height */
   width2 = htons(WIDTH);
   height2 = htons(HEIGHT);
-  ret = write_exact((const u_char *)&width2, sizeof(uint16_t));
-  ret = write_exact((const u_char *)&height2, sizeof(uint16_t));
+  write_uint16(&width2);
+  write_uint16(&height2);
 
   /* webcam PNG */
-  ret = write_exact(png_bin->data, png_size*sizeof(u_char));
+  write_binary(png_bin->data, png_size);
   g_byte_array_free(png_bin, TRUE);
 
   /* Ack */
   send_ack(ctx, BINIOU_CHAR, 255);
 }
+#endif
 
 
 /* Process any command coming from the erlang side */
@@ -490,15 +465,14 @@ command(Context_t *ctx)
   uint32_t pkt_size, pkt_size2;
   u_char *cmd;
   ssize_t res;
-  int ret;
 
-  ret = set_nonblocking(IN_FD, 1); /* FIXME do something with ret */
+  set_nonblocking(IN_FD, 1); /* FIXME error checking */
 
   res = read_exact((u_char *)&pkt_size, sizeof(uint32_t));
   if (-1 == res)
     return 0;
 
-  ret = set_nonblocking(IN_FD, 0); /* FIXME do something with ret */
+  set_nonblocking(IN_FD, 0); /* FIXME error checking */
 
   pkt_size2 = ntohl(pkt_size);
 
@@ -512,6 +486,7 @@ command(Context_t *ctx)
       return -1;
     }
 
+#ifdef WITH_WEBCAM
     if (WEBCAM_CHAR == cmd[0]) {
       send_webcam(ctx);
       xfree(cmd);
@@ -523,11 +498,13 @@ command(Context_t *ctx)
       xfree(cmd);
       return 1;
     }
+#endif
 
     xerror("Unknown 1-byte command %d\n", cmd[0]);
   }
 
   if (2 == res) { /* got 2 bytes */
+#if 0
     if (WEBCAM_CHAR == cmd[0]) {
       switch (cmd[1]) {
       case 0: /* set local */
@@ -549,7 +526,7 @@ command(Context_t *ctx)
       xfree(cmd);
       return 1;
     }
-
+#endif
     xerror("Unknown 2-byte command %d\n", cmd[0]);
   }
 
@@ -606,11 +583,13 @@ command(Context_t *ctx)
     return 1;
   }
 
+#ifdef WITH_WEBCAM
   if ((WEBCAM_CHAR == cmd[0]) && (pkt_size2 >= (sizeof(u_char)+2*sizeof(uint16_t)))) {
     uint16_t *width, width2;
     uint16_t *height, height2;
     png_t png;
-    Buffer8_t *dst = ctx->buffers[CAM_OUT_BUFFER];
+    Buffer8_t *dst = ctx->cam_save[ctx->cam][0];
+    int ret;
 
     width = (uint16_t *)&cmd[1];
     height = (uint16_t *)&cmd[3];
@@ -645,6 +624,7 @@ command(Context_t *ctx)
     if (pkt_size2)
       xerror("Wrong webcam command (%lu bytes)\n", pkt_size2);
   }
+#endif
 
   if (res)
     xerror("Got wrong packet length from erlang: %lu\n", res);
@@ -669,7 +649,6 @@ run(Context_t *ctx)
 
   if (res == -1) {
     u_char c = STOP_CHAR;
-    int ret;
     
     ctx->running = 0;
 
@@ -677,15 +656,15 @@ run(Context_t *ctx)
     /* send packet size */
     total = sizeof(char);
     total2 = htonl(total);
-    ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
+    write_uint32(&total2);
 
     /* send STOP_CHAR */
-    ret = write_exact((const u_char *)&c, sizeof(u_char));
-
-    /* XXX keep gcc happy */
-    ret++; /* <- remove this ! */
+    write_uint8(&c);
   } else {
     switch (proto) {
+    case '0':
+      break;
+
     case '1':
       v1(ctx);
       break;
@@ -714,6 +693,10 @@ run(Context_t *ctx)
       v7(ctx);
       break;
 
+    case '8':
+      v8(ctx);
+      break;
+
     default:
       xerror("Unknown protocol version\n");
       break;
