@@ -19,6 +19,7 @@
 
 #include <arpa/inet.h>
 #include "context.h"
+#include "erlang.h"
 
 /*
  * Protocol v1:
@@ -27,11 +28,6 @@
  * [ image data ] (RGB)   W*H*3 bytes
  *
  */
-
-extern FILE *out;
-extern void xfwrite(const void *, size_t, size_t, FILE *);
-
-
 void
 v1(const Context_t *ctx)
 {
@@ -42,23 +38,23 @@ v1(const Context_t *ctx)
   Pixel_t *src;
 
   /* send packet size */
-  total = sizeof(uint32_t)+2*sizeof(uint16_t)+BUFFSIZE*3*sizeof(u_char);
+  total = sizeof(uint32_t)+2*sizeof(uint16_t)+RGB_BUFFSIZE*sizeof(u_char);
   total2 = htonl(total);
-  xfwrite((const void *)&total2, sizeof(uint32_t), 1, out);
+  write_uint32(&total2);
   
   /* protocol version */
   proto2 = htonl(proto);
-  xfwrite((const void *)&proto2, sizeof(uint32_t), 1, out);
+  write_uint32(&proto2);
   
   /* send width, height */
   width2 = htons(width);
   height2 = htons(height);
-  xfwrite((const void *)&width2, sizeof(uint16_t), 1, out);
-  xfwrite((const void *)&height2, sizeof(uint16_t), 1, out);
+  write_uint16(&width2);
+  write_uint16(&height2);
   
   /* send picture */
   src = export_RGB_active_buffer(ctx, 0);
-  xfwrite((const void *)src, sizeof(u_char), BUFFSIZE*3, out);
+  write_binary(src, RGB_BUFFSIZE);
   xfree(src);
 }
 
