@@ -20,6 +20,7 @@
 #include <arpa/inet.h>
 #include <GL/gl.h>
 #include "context.h"
+#include "erlang.h"
 
 /*
  * Protocol v4:
@@ -29,11 +30,6 @@
  * [ image data ]         W*H bytes
  *
  */
-
-extern FILE *out;
-extern void xfwrite(const void *, size_t, size_t, FILE *);
-
-
 void
 v4(const Context_t *ctx)
 {
@@ -47,25 +43,23 @@ v4(const Context_t *ctx)
   /* send packet size */
   total = sizeof(uint32_t)+2*sizeof(uint16_t)+256*sizeof(rgba_t)+BUFFSIZE*sizeof(u_char);
   total2 = htonl(total);
-  xfwrite((const void *)&total2, sizeof(uint32_t), 1, out);
+  write_uint32(&total2);
   
   /* protocol version */
   proto = 4;
   proto2 = htonl(proto);
-  xfwrite((const void *)&proto2, sizeof(uint32_t), 1, out);
+  write_uint32(&proto2);
 
   /* send width, height */
   width2 = htons(width);
   height2 = htons(height);
-  xfwrite((const void *)&width2, sizeof(uint16_t), 1, out);
-  xfwrite((const void *)&height2, sizeof(uint16_t), 1, out);
+  write_uint16(&width2);
+  write_uint16(&height2);
 
   /* send colormap */
-  //  for (i = 0; i < 256; i++)
-  xfwrite((const void *)colors, sizeof(rgba_t), 256, out);
+  write_binary((uint8_t *)colors, 256*sizeof(rgba_t));
 
   /* send picture */
   src = active_buffer(ctx)->buffer;
-  xfwrite((const void *)src, sizeof(u_char), BUFFSIZE, out);
-  /*  xfree(src); */
+  write_binary(src, BUFFSIZE);
 }
