@@ -19,40 +19,33 @@
 
 #include <arpa/inet.h>
 #include "context.h"
+#include "erlang.h"
 
 /*
  * Protocol v6:
  * [ image data ] (RGB)   W*H*3 bytes (image, flipped)
  *
  */
-
-extern int write_exact(const u_char *, const int);
-
-
 void
 v6(const Context_t *ctx)
 {
   uint32_t proto = 6, proto2;
   uint32_t total, total2;
   Pixel_t *src;
-  int ret;
 
   /* send packet size */
-  total = sizeof(uint32_t)+BUFFSIZE*3*sizeof(u_char);
+  total = sizeof(uint32_t)+RGB_BUFFSIZE*sizeof(u_char);
   total2 = htonl(total);
-  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
+  write_uint32(&total2);
   
   /* protocol version */
   proto2 = htonl(proto);
-  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
+  write_uint32(&proto2);
   
   /* send picture */
   src = export_RGB_active_buffer(ctx, 1);
-  ret = write_exact((const u_char *)src, sizeof(u_char)*BUFFSIZE*3);
+  write_binary(src, RGB_BUFFSIZE);
   xfree(src);
-
-  /* XXX keep gcc happy */
-  ret++; /* <- remove this ! */
 }
 
 
