@@ -232,11 +232,13 @@ biniou_stop()
 void
 biniou_load_input(const char *dir, const char *name)
 {
-  Plugin_t *p;
+  Plugin_t *p = NULL;
 
   p = Plugin_new(dir, name, PL_INPUT);
-  Plugin_init(p);
-  context->input_plugin = p;
+  if (NULL != p) {
+    Plugin_init(p);
+    context->input_plugin = p;
+  }
 }
 
 
@@ -251,7 +253,7 @@ biniou_set_input(Input_t *input)
 void
 biniou_load_output(const char *dir, const char *name)
 {
-  Plugin_t *p;
+  Plugin_t *p = NULL;
   gchar **tokens, **output;
   
   assert(NULL != context);
@@ -261,8 +263,10 @@ biniou_load_output(const char *dir, const char *name)
 
   for ( ; *output != NULL; output++) {
     p = Plugin_new(dir, *output, PL_OUTPUT);
-    Plugin_init(p);
-    context->outputs = g_slist_prepend(context->outputs, p);
+    if (NULL != p) {
+      Plugin_init(p);
+      context->outputs = g_slist_prepend(context->outputs, p);
+    }
   }
 
   g_strfreev(tokens);
