@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -29,7 +29,11 @@
 #define B_INIT_VERBOSE      4
 #define B_INIT_ALL          (B_INIT_SEQUENCES|B_INIT_SCHEMES)
 
-void biniou_new(const char *, const char *, const char *, const char *, const u_short, const u_short, const u_char);
+void biniou_new(const char *, const char *, const char *, const char *,
+#ifndef FIXED
+		const u_short, const u_short,
+#endif
+		const u_char);
 void biniou_delete();
 
 /* vla le bordel */
