@@ -29,9 +29,9 @@
 Buffer8_t *
 Buffer8_new()
 {
-  Buffer8_t *buff = xcalloc(1, sizeof(Buffer8_t));
+  Buffer8_t *buff = av_malloc(sizeof(Buffer8_t));
 
-  buff->buffer = xcalloc(BUFFSIZE, sizeof(Pixel_t));
+  buff->buffer = av_malloc(BUFFSIZE*sizeof(Pixel_t));
 
   return buff;
 }
@@ -40,9 +40,9 @@ Buffer8_new()
 Buffer8_t *
 Buffer8_clone(const Buffer8_t *src)
 {
-  Buffer8_t *buff = xmalloc(sizeof(Buffer8_t));
+  Buffer8_t *buff = av_malloc(sizeof(Buffer8_t));
 
-  buff->buffer = xmalloc(BUFFSIZE*sizeof(Pixel_t));
+  buff->buffer = av_malloc(BUFFSIZE*sizeof(Pixel_t));
   Buffer8_copy(src, buff);
 
   return buff;
@@ -52,8 +52,8 @@ Buffer8_clone(const Buffer8_t *src)
 void
 Buffer8_delete(Buffer8_t *buff)
 {
-  xfree(buff->buffer);
-  xfree(buff);
+  av_free(buff->buffer);
+  av_free(buff);
 }
 
 
@@ -313,9 +313,11 @@ Buffer8_average(Buffer8_t *s1, const Buffer8_t *s2)
 void
 gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const Pixel_t *grey_data)
 {
+  int srcStride[4]={0,0,0,0};
+  int dstStride[4]={0,0,0,0};
+  const uint8_t *srcSlice[4]={NULL,NULL,NULL,NULL};
+  uint8_t *dst[4]={NULL,NULL,NULL,NULL};
   struct SwsContext *sws_context = NULL;
-  int srcStride[4]={0,0,0,0}, dstStride[4]={0,0,0,0};
-  uint8_t *srcSlice[4]={NULL,NULL,NULL,NULL}, *dst[4]={NULL,NULL,NULL,NULL};
   int ret;
 
   sws_context = sws_getContext(width, height, PIX_FMT_GRAY8,
@@ -326,10 +328,14 @@ gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const
 
   srcStride[0] = width;
   dstStride[0] = WIDTH;
-  srcSlice[0] = (uint8_t *)grey_data;
-  dst[0] = grey_to;
+  srcSlice[0] = (const uint8_t *)grey_data;
+  dst[0] = (uint8_t *)grey_to;
 
-  ret = sws_scale(sws_context, (const uint8_t * const *)srcSlice, srcStride, 0, height, dst, dstStride);
+#if LIBSWSCALE_VERSION_MAJOR == 2
+  ret = sws_scale(sws_context, srcSlice, srcStride, 0, height, dst, dstStride);
+#else
+  ret = sws_scale(sws_context, (uint8_t **)srcSlice, srcStride, 0, height, dst, dstStride);
+#endif
   if (ret < 0)
     xerror("sws_scale\n");
 
