@@ -20,6 +20,7 @@
 #ifndef __BINIOU_BUFFER_8BITS_H
 #define __BINIOU_BUFFER_8BITS_H
 
+#include <string.h>
 #include "utils.h"
 #include "constants.h"
 #include "point2d.h"
@@ -454,7 +455,7 @@ void Buffer8_average(Buffer8_t *, const Buffer8_t *);
 
 
 static inline void
-Buffer8_flip_x(Buffer8_t *buff)
+Buffer8_flip_v(Buffer8_t *buff)
 {
   u_short j;
 
@@ -469,7 +470,7 @@ Buffer8_flip_x(Buffer8_t *buff)
 
 
 static inline void
-Buffer8_flip_y(Buffer8_t *buff)
+Buffer8_flip_h(Buffer8_t *buff)
 {
   u_short j;
 
