@@ -31,7 +31,7 @@ CmapFader_new(const u_short size)
   cf->on = 0;
   cf->cur = Cmap8_new();
   cf->dst = colormaps->cmaps[0];
-  cf->fader = Fader_new(256*3);
+  cf->fader = Fader_new(256*4);
   cf->shf = Shuffler_new(size);
   Shuffler_set_mode(cf->shf, BS_RANDOM);
 #ifdef XDEBUG
@@ -65,8 +65,8 @@ CmapFader_init(CmapFader_t *cf)
 	
   for (i = 0; i < 256; i++) {
     /* TODO pointer chain optim */
-    const _rgba_t col_src = cf->cur->colors[i].col;
-    const _rgba_t col_dst = cf->dst->colors[i].col;
+    const RGBA_t col_src = cf->cur->colors[i].col;
+    const RGBA_t col_dst = cf->dst->colors[i].col;
 
     /* delta values */
 /*     cf->fader->delta[i*3+0] = */
@@ -87,6 +87,9 @@ CmapFader_init(CmapFader_t *cf)
     fader->delta[i*3+2] = (long)
       ((float)col_dst.b-(float)col_src.b)
       / (float)(fader->max)*MFACTOR;
+    fader->delta[i*3+3] = (long)
+      ((float)col_dst.a-(float)col_src.a)
+      / (float)(fader->max)*MFACTOR;
 		
     /* initial values */
 /*     cf->fader->tmp[i*3+0] = (float)col_src.r; */
@@ -95,6 +98,7 @@ CmapFader_init(CmapFader_t *cf)
     fader->tmp[i*3+0] = (u_long)col_src.r*MFACTOR;
     fader->tmp[i*3+1] = (u_long)col_src.g*MFACTOR;
     fader->tmp[i*3+2] = (u_long)col_src.b*MFACTOR;
+    fader->tmp[i*3+3] = (u_long)col_src.a*MFACTOR;
   }
 
   Fader_start(fader);
@@ -131,6 +135,12 @@ CmapFader_run(CmapFader_t *cf)
       cur->colors[i].col.b =
 	(u_char)((fader->tmp[i*3+2] +=
 		  elapsed*fader->delta[i*3+2])/MFACTOR);
+
+      /* FIXME alpha fading seems broken */
+      cur->colors[i].col.a = 255;
+      /* cur->colors[i].col.a = */
+      /* 	(u_char)((fader->tmp[i*3+3] += */
+      /* 		  elapsed*fader->delta[i*3+3])/MFACTOR); */
     }	
   }
   Cmap8_findMinMax(cur);
