@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,8 +24,8 @@
 
 
 typedef struct Colormaps_s {
-  Cmap8_t **cmaps;
-  u_short size;
+  Cmap8_t  **cmaps;
+  uint16_t size;
 } Colormaps_t;
 
 extern Colormaps_t  *colormaps;
@@ -34,9 +34,9 @@ extern Colormaps_t  *colormaps;
 void Colormaps_new(const char *);
 void Colormaps_delete();
 
-const char *Colormaps_name(const long);
-int Colormaps_index(const long);
-long Colormaps_find(const char *);
-long Colormaps_random_id();
+const char *Colormaps_name(const uint32_t);
+int32_t Colormaps_index(const uint32_t);
+int32_t Colormaps_find(const char *);
+uint32_t Colormaps_random_id();
 
 #endif /* __BINIOU_COLORMAPS_H */
