@@ -24,7 +24,9 @@
 #ifndef FIXED
 extern unsigned short WIDTH, HEIGHT;
 #endif
-#define BUFFSIZE   (unsigned long)(WIDTH*HEIGHT)
+#define BUFFSIZE      (unsigned long)(WIDTH*HEIGHT)
+#define RGB_BUFFSIZE  (3*BUFFSIZE)
+#define RGBA_BUFFSIZE (4*BUFFSIZE)
 
 /* min/max indices */
 #define MINX       (0)
@@ -52,7 +54,7 @@ extern unsigned short WIDTH, HEIGHT;
 #define MAXLEN     _POSIX2_LINE_MAX
 
 /* maximum length of a sequence */
-#define MAX_SEQ_LEN	255
+#define MAX_SEQ_LEN	254
 
 /* handy shortcuts */
 #define DEC(val, maxval) do { if (!val) val = maxval-1; else --val; } while (0)
@@ -70,6 +72,6 @@ enum OSDMode { OSD_NONE=0, OSD_MINI, OSD_FULL, OSD_FULL_BG };
 
 #define MAX_BANKS 12
 
-#define ZMAX 5.0
+#define ZMAX 6.0
 
 #endif /* __BINIOU_CONSTANTS_H */
