@@ -23,39 +23,71 @@
 #include "pictures.h"
 #include "colormaps.h"
 #include "sequences.h"
-#include "webcam.h"
 
 
 #define DELAY_MIN 15
 #define DELAY_MAX 30
 
 
+#ifdef WITH_WEBCAM
+#include "webcam.h"
+
+extern int webcams;
+extern char *video_base;
+
+
+static webcam_t *cams[MAX_CAMS];
+static pthread_t thr[MAX_CAMS];
+
+#define MAX_TRIES 5
+
+
 static void
 Context_open_webcam(Context_t *ctx)
 {
-#if HAVE_LINUX_VIDEODEV2_H
-  fd = -1;
-
-  pthread_mutex_init(&ctx->cam_mtx, NULL);
+  int i;
+  uint8_t try = 0;
 
   parse_options();
-  if (-1 != open_device())
-    if (-1 != init_device()) {
-      ctx->has_cam = 1;
-      enumerate_cids();
-      start_capturing();
-    }
 
-  if (ctx->has_cam)
-    pthread_create(&thr, NULL, loop, (void *)ctx);
-#endif
+  for (i = 0; i < MAX_CAMS; i++)
+    pthread_mutex_init(&ctx->cam_mtx[i], NULL);
+
+  for (i = 0; (i < webcams) && (try < MAX_TRIES); i++) {
+  retry:
+    cams[i] = xmalloc(sizeof(webcam_t));
+
+    cams[i]->io = IO_METHOD_MMAP;
+    cams[i]->fd = -1;
+    cams[i]->ctx = ctx;
+    cams[i]->cam_no = i;
+
+    if (-1 != open_device(cams[i], try)) {
+      if (-1 != init_device(cams[i])) {
+	enumerate_cids(cams[i]);
+	list_inputs(cams[i]);
+	start_capturing(cams[i]);
+
+	pthread_create(&thr[i], NULL, loop, (void *)cams[i]);
+      } else {
+	fprintf(stderr, "[i] Webcam: failed to initialize device #%d\n", i);
+	close_device(cams[i]);
+	xfree(cams[i]);
+	try++;
+	goto retry;
+      }
+    } else
+      xfree(cams[i]);
+  }
 }
+#endif
 
 
 Context_t *
 Context_new()
 {
   int i;
+
   Context_t *ctx = xcalloc(1, sizeof(Context_t));
 
   ctx->running = 1;
@@ -67,14 +99,24 @@ Context_new()
       printf("%d ", i);
     ctx->buffers[i] = Buffer8_new();
   }
-  for (i = 0; i < CAM_SAVE; i++)
-    ctx->cam_save[i] = Buffer8_new();
+#ifdef WITH_WEBCAM
+  {
+    int k;
+    for (k = 0; k < webcams; k++) {
+      for (i = 0; i < CAM_SAVE; i++)
+	ctx->cam_save[k][i] = Buffer8_new();
+      ctx->cam_ref[k] = Buffer8_new();
+      ctx->rgba_cam_buffers[k] = BufferRGBA_new();
+    }
+  }
+#endif
   ctx->rgba_buffers[ACTIVE_BUFFER] = BufferRGBA_new();
   if (libbiniou_verbose)
     printf("\n");
 
 #if WITH_GL
   glGenTextures(NSCREENS, ctx->textures); // TODO: delete on exit
+  glGenTextures(MAX_CAMS, ctx->cam_textures); // TODO: delete on exit
 #endif
 
   if (pictures != NULL) {
@@ -123,11 +165,6 @@ Context_new()
 
   ctx->outputs = NULL;
 
-  ctx->cam = CAM_IN_BUFFER;
-  ctx->has_cam = 0;
-
-  Context_open_webcam(ctx);
-
 #ifdef FEAT_TARGET
   ctx->target = 1; /* maybe someday we want a switch to disable,
 		      or worse, a global variable :) */
@@ -148,21 +185,32 @@ Context_new()
   }
 #endif
 
+#ifdef WITH_WEBCAM
+  printf("[i] Initialiazing %d webcams base: %s\n", webcams, video_base);
+
+  ctx->cam = 0;
+  Context_open_webcam(ctx);
+
+  for (i = 0; i < webcams; i++)
+    Buffer8_copy(ctx->target_pic->buff, ctx->cam_save[i][0]);
+#endif
+
   return ctx;
 }
 
 
+#ifdef WITH_WEBCAM
 static void
-Context_close_webcam(__attribute__ ((unused)) Context_t *ctx)
+Context_close_webcam(const u_char cam_no)
 {
-#if HAVE_LINUX_VIDEODEV2_H
-  pthread_join(thr, NULL);
-  stop_capturing();
-  uninit_device();
-  close_device();
-  free(dev_name);
-#endif
+  if (NULL != cams[cam_no]) {
+    pthread_join(thr[cam_no], NULL);
+    stop_capturing(cams[cam_no]);
+    uninit_device(cams[cam_no]);
+    close_device(cams[cam_no]);
+  }
 }
+#endif
 
 
 void
@@ -171,8 +219,15 @@ Context_delete(Context_t *ctx)
   int i;
   GSList *outputs = ctx->outputs;
 
-  if (ctx->has_cam)
-    Context_close_webcam(ctx);
+#ifdef WITH_WEBCAM
+  if (webcams) {
+    int i;
+
+    for (i = 0; i < webcams; i++)
+      Context_close_webcam(i);
+  }
+  xfree(video_base);
+#endif
 
   if (libbiniou_verbose)
     printf("[i] %lu frames, %lu events\n", ctx->frames, ctx->nb_events);
@@ -194,8 +249,17 @@ Context_delete(Context_t *ctx)
       printf("%d ", i);
     Buffer8_delete(ctx->buffers[i]);
   }
-  for (i = 0; i < CAM_SAVE; i++)
-    Buffer8_delete(ctx->cam_save[i]);
+#ifdef WITH_WEBCAM
+  {
+    int k;
+    for (k = 0; k < webcams; k++) {
+      for (i = 0; i < CAM_SAVE; i++)
+	Buffer8_delete(ctx->cam_save[k][i]);
+      Buffer8_delete(ctx->cam_ref[k]);
+      BufferRGBA_delete(ctx->rgba_cam_buffers[k]);
+    }
+  }
+#endif
   BufferRGBA_delete(ctx->rgba_buffers[ACTIVE_BUFFER]);
   if (libbiniou_verbose)
     printf("\n");
@@ -599,13 +663,15 @@ passive_buffer(const Context_t *ctx)
 }
 
 
+#ifdef WITH_WEBCAM
 void
-Context_push_webcam(Context_t *ctx, Buffer8_t *buff)
+Context_push_webcam(Context_t *ctx, Buffer8_t *buff, const int cam)
 {
   int i;
 
-  Buffer8_delete(ctx->cam_save[CAM_SAVE-1]);
+  Buffer8_delete(ctx->cam_save[cam][CAM_SAVE-1]);
   for (i = CAM_SAVE-1; i >= 1; i--)
-    ctx->cam_save[i] = ctx->cam_save[i-1];
-  ctx->cam_save[0] = buff;
+    ctx->cam_save[cam][i] = ctx->cam_save[cam][i-1];
+  ctx->cam_save[cam][0] = buff;
 }
+#endif
