@@ -37,13 +37,17 @@
 
 enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 
-#define NSCREENS 6
 #define ACTIVE_BUFFER  0
 #define PASSIVE_BUFFER 1
 #define SAVE_BUFFER    2
-#define CAM_IN_BUFFER  3
-#define CAM_REF_BUFFER 4
-#define CAM_OUT_BUFFER 5
+
+#ifdef WITH_WEBCAM
+#define NSCREENS 6 /* <--- ??? oliv3 */
+#else
+#define NSCREENS 3
+#endif
+
+#define MAX_CAMS       2
 
 /* store the last N frames from the webcam -same as EffectTV */
 #define CAM_SAVE 32
@@ -66,14 +70,15 @@ typedef struct Context_s {
   /* 0 = active_buffer
    * 1 = passive_buffer - for double-buffering
    * 2 = save_buffer    - push/pop screen for lens effects
-   * 3 = camera input
-   * 4 = camera reference
-   * 5 = camera output
    */
 
+#ifdef WITH_WEBCAM
   /* webcam */
-  Buffer8_t *cam_save[CAM_SAVE];
-  char ref_taken:1;
+  Buffer8_t *cam_save[MAX_CAMS][CAM_SAVE];
+  Buffer8_t *cam_ref[MAX_CAMS];
+  BufferRGBA_t *rgba_cam_buffers[MAX_CAMS];
+  char ref_taken[MAX_CAMS];
+#endif
 
   /* Faders */
   PictFader_t *pf;
@@ -120,10 +125,11 @@ typedef struct Context_s {
   u_char   bankset[3];
   u_char   bank[3]; /* the bank used */
 
+#ifdef WITH_WEBCAM
   /* Webcam */
-  u_char has_cam;
-  pthread_mutex_t cam_mtx;
-  u_char cam;
+  pthread_mutex_t cam_mtx[MAX_CAMS];
+  u_char cam; /* active webcam */
+#endif
 
   /* OpenGL */
 #ifdef WITH_GL
@@ -131,6 +137,9 @@ typedef struct Context_s {
   char texture_used:1;
   char gl_done:1;
   GLuint textures[NSCREENS];
+  GLuint cam_textures[MAX_CAMS];
+  char pulse_3d:1;
+  char force_cube:1;
 #endif
 
   /* Target */
@@ -214,6 +223,8 @@ pop_buffer(const Context_t *ctx)
 /* TODO: deprecate export_RGB*, use export RGBA* */
 Pixel_t *export_RGB_buffer(const Context_t *, const u_char, const u_char);
 Pixel_t *export_RGB_active_buffer(const Context_t *, const u_char);
+Pixel_t *export_YUV_buffer(const Context_t *, const u_char, const u_char);
+Pixel_t *export_YUV_active_buffer(const Context_t *, const u_char);
 const RGBA_t *export_RGBA_buffer(const Context_t *, const u_char);
 const RGBA_t *export_RGBA_active_buffer(const Context_t *);
 
@@ -224,8 +235,11 @@ void Context_clear_bank(Context_t *, const u_char);
 void Context_store_bank(Context_t *, const u_char);
 void Context_use_bankset(Context_t *, const u_char);
 
-void Context_push_webcam(Context_t *, Buffer8_t *);
+void Context_push_webcam(Context_t *, Buffer8_t *, const int);
 
-void Context_make_GL_texture(Context_t *ctx, const u_char);
+void Context_make_GL_RGBA_texture(Context_t *ctx, const u_char);
+#ifdef WITH_WEBCAM
+void Context_make_GL_gray_texture(Context_t *ctx, const u_char);
+#endif
 
 #endif /* __BINIOU_CONTEXT_H */
