@@ -22,6 +22,10 @@
 #include "colormaps.h"
 #include "pictures.h"
 
+#ifdef WITH_WEBCAM
+extern int webcams;
+#endif
+
 
 void
 Context_add_event(Context_t *ctx, const Event_t *e)
@@ -207,6 +211,18 @@ Context_event(Context_t *ctx, const Event_t *e)
       return 1;
       break;
 
+#ifdef WITH_GL
+    case BA_PULSE:
+      ctx->pulse_3d = !ctx->pulse_3d;
+      return 1;
+      break;
+
+    case BA_BOUNDARY:
+      ctx->force_cube = !ctx->force_cube;
+      return 1;
+      break;
+#endif
+
     default:
       return 0;
       break;
@@ -304,6 +320,12 @@ Context_event(Context_t *ctx, const Event_t *e)
 	return 1;
       }
 
+#ifdef WITH_WEBCAM
+    case BA_WEBCAM:
+      ctx->cam = (ctx->cam+1) % webcams;
+      return 1;
+#endif
+
     default:
       return 0;
     }
@@ -403,14 +425,16 @@ Context_event(Context_t *ctx, const Event_t *e)
     }
     break;
 
+#ifdef WITH_WEBCAM
   case BC_SET:
     if (e->arg0 == BA_WEBCAM) {
-      pthread_mutex_lock(&ctx->cam_mtx);
-      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->buffers[CAM_REF_BUFFER]);
-      pthread_mutex_unlock(&ctx->cam_mtx);
+      pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+      Buffer8_copy(ctx->cam_save[ctx->cam][0], ctx->cam_ref[ctx->cam]);
+      pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
       return 1;
     }
     break;
+#endif
 
   case BC_STORE_BANK:
     printf("[i] Storing sequence/colormap/picture in bank #%d\n", e->arg0+1);
