@@ -27,7 +27,7 @@ export_RGB_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
   Buffer8_t *buf = ctx->buffers[screen];
   const Pixel_t *src = NULL;
   Pixel_t *res;
-  u_long c, i=0;
+  u_long c, i = 0;
 
   if (flip)
     Buffer8_flip_v(buf);
@@ -55,6 +55,52 @@ export_RGB_active_buffer(const Context_t *ctx, const u_char flip)
 }
 
 
+Pixel_t *
+export_YUV_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
+{
+  rgba_t *colors = &ctx->cf->cur->colors[0];
+  Buffer8_t *buf = ctx->buffers[screen];
+  const Pixel_t *src = NULL;
+  Pixel_t *res;
+  u_long c, i = 0;
+
+  if (flip)
+    Buffer8_flip_v(buf);
+  src = buf->buffer;
+
+  res = xmalloc(3*BUFFSIZE*sizeof(Pixel_t));
+
+  /*
+   * From wikipedia, sorry
+   *
+   * Y = 0,299⋅R + 0,587⋅G + 0,114⋅B
+   * U = 0,492⋅(B − Y) = −0,14713⋅R − 0,28886⋅G + 0,436⋅B
+   * V = 0,877⋅(R − Y) = 0,615⋅R − 0,51498⋅G- 0,10001⋅B
+   */
+#define CR (colors[src[c]].col.r)
+#define CG (colors[src[c]].col.g)
+#define CB (colors[src[c]].col.b)
+
+  for (c = 0; c < BUFFSIZE; c++) {
+    res[i++] = 0.299*CR + 0.587*CG + 0.114*CB;;
+    res[i++] = -0.14713*CR - 0.28886*CG + 0.436*CB;
+    res[i++] = 0.615*CR - 0.51498*CG - 0.10001*CB;
+  }
+
+  if (flip)
+    Buffer8_flip_v(buf);
+
+  return res;
+}
+
+
+Pixel_t *
+export_YUV_active_buffer(const Context_t *ctx, const u_char flip)
+{
+  return export_YUV_buffer(ctx, ACTIVE_BUFFER, flip);
+}
+
+
 const RGBA_t *
 export_RGBA_buffer(const Context_t *ctx, const u_char screen)
 {
