@@ -21,33 +21,40 @@
 
 
 void
-Context_make_GL_texture(Context_t *ctx, const u_char screen)
+Context_make_GL_RGBA_texture(Context_t *ctx, const u_char screen)
 {
   GLuint texture;
   const RGBA_t *data = NULL;
 
   texture = ctx->textures[screen];
-
-  /*
-  glGenTextures(1, texture);
-  if (!texture)
-    xerror("glGenTextures");
-  */
   data = export_RGBA_buffer(ctx, screen);
 
-  // glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
-
   glEnable(GL_TEXTURE_2D);
-  // glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_DECAL);
-
   glBindTexture(GL_TEXTURE_2D, texture);
-  // glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
-  // glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
-  //  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-  //glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
   glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, WIDTH, HEIGHT, 0,
-	       //glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0,
 	       GL_RGBA, GL_UNSIGNED_BYTE, data);
 }
+
+
+#ifdef WITH_WEBCAM
+void
+Context_make_GL_gray_texture(Context_t *ctx, const u_char cam)
+{
+  GLuint texture;
+  const Pixel_t *data = NULL;
+
+  texture = ctx->cam_textures[cam];
+  pthread_mutex_lock(&ctx->cam_mtx[cam]);
+  data = ctx->cam_save[cam][0]->buffer;
+
+  glEnable(GL_TEXTURE_2D);
+  glBindTexture(GL_TEXTURE_2D, texture);
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+  glTexImage2D(GL_TEXTURE_2D, 0, GL_LUMINANCE, WIDTH, HEIGHT, 0,
+	       GL_LUMINANCE, GL_UNSIGNED_BYTE, data);
+  pthread_mutex_unlock(&ctx->cam_mtx[cam]);
+}
+#endif
