@@ -127,7 +127,7 @@ Context_sequence(Context_t *ctx)
     tmp = g_list_next(tmp);
   }
 #ifdef FEAT_TARGET
-  if (!count && ctx->target) {
+  if (!count && ctx->random_mode && ctx->target) {
     assert(NULL != ctx->target_pic);
     Buffer8_copy(ctx->target_pic->buff, active_buffer(ctx));
   }
@@ -201,9 +201,6 @@ Context_run(Context_t *ctx)
   /* 3D stuff */
   if (ctx->params3d.do_auto_rotate)
     Params3d_change_rotations(&ctx->params3d);
-#ifdef Z_BUFFER
-  Params3d_init_z_buffer();
-#endif
 
 #ifdef WITH_GL
   glClearColor(0, 0, 0, 0);
@@ -214,9 +211,9 @@ Context_run(Context_t *ctx)
   glLoadIdentity();
 
   gluPerspective(ctx->params3d.gl_fov, (float)WIDTH/(float)HEIGHT,
-		 0.1, ZMAX);
-  gluLookAt(0, 0, 3.14,
-	    0, 0, -3.14,
+		 0.1, 10); //ZMAX);
+  gluLookAt(0, 0, 5, //3.14,
+	    0, 0, -1, //-3.14,
 	    0, 1, 0);
 
   glShadeModel(GL_SMOOTH);
@@ -233,6 +230,10 @@ Context_run(Context_t *ctx)
 
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
+  if (ctx->pulse_3d) {
+    float scale = Input_get_volume(ctx->input) + 1.0;
+    glScalef(scale, scale, scale);
+  }
 #endif
 
   /* The sequence */
@@ -253,6 +254,9 @@ Context_run(Context_t *ctx)
     Buffer8_color_bar(active_buffer(ctx), BARSIZE);
   }
 
+  /* Process events */
+  Context_process_events(ctx);
+
   /* TODO: use plugin on_key callback */
   for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
@@ -269,9 +273,6 @@ Context_run(Context_t *ctx)
   /* All outputs should have refreshed their cmap by now */
   ctx->cf->refresh = 0;
 
-  /* Process events */
-  Context_process_events(ctx);
-
   /* Screenshot */
   if (ctx->take_screenshot) {
     Context_screenshot(ctx);
