@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -19,7 +19,9 @@
 
 #include "globals.h"
 
+#ifndef FIXED
 u_short     WIDTH, HEIGHT;
+#endif
 
 Plugins_t   *plugins   = NULL;
 Sequences_t *sequences = NULL;
