@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -25,9 +25,10 @@
 #include "schemes.h"
 #include "context.h"
 
+#ifndef FIXED
 extern u_short      WIDTH;
 extern u_short      HEIGHT;
-
+#endif
 extern Plugins_t    *plugins;
 extern Sequences_t  *sequences;
 extern Schemes_t    *schemes;
