@@ -53,6 +53,7 @@ Input_new(const u_short size)
 #ifdef THREAD_PLAN
   pthread_t fftw_thread; 
 #endif
+  char *pipe_name = NULL;
 
   Input_t *input = xcalloc(1, sizeof(Input_t));
 
@@ -65,9 +66,17 @@ Input_new(const u_short size)
   printf("[w] data size= %d, power spectrum size= %d\n",
 	 input->size, input->spectrum_size);
 
+  if (NULL != (pipe_name = getenv("BINIOU_AUDIO_PIPE"))) {
+    input->raw = xcalloc(2*size, sizeof(int16_t));
+    input->pipe = open(pipe_name, O_WRONLY);
+    if (-1 == input->pipe)
+      xperror("open");
+  } else
+    input->pipe = -1;
+
   for (c = 0; c < 3; c++) {
     /* FIXME breaks when compiling without libFFTW */
-    input->data[c]   = (double *)fftw_malloc(sizeof(double) * input->size);
+    input->data[c]   = (double *)fftw_malloc(sizeof(double)*input->size);
     input->data_u[c] = xcalloc(input->size, sizeof(double));
     input->out[c] = (double *)fftw_malloc(sizeof(double) * input->size);
     input->spectrum[c] = xcalloc(input->spectrum_size, sizeof(double));
@@ -76,6 +85,11 @@ Input_new(const u_short size)
     input->spectrum_log_norme[c] = xcalloc(input->spectrum_size, sizeof(double));
   }
 
+  for (c = 0; c < input->size; c++) {
+    input->data[A_LEFT][c] = input->data_u[A_LEFT][c] = 0;
+    input->data[A_RIGHT][c] = input->data_u[A_RIGHT][c] = 0;
+  }
+
 #ifdef THREAD_PLAN
   pthread_create(&fftw_thread, NULL, Input_rfftw_create_plan_threaded, input);
 #else
@@ -102,6 +116,9 @@ Input_delete(Input_t *input)
     fftw_destroy_plan(input->plan_fft[c]);
   }
 
+  if (-1 != input->pipe)
+    close(input->pipe);
+  xfree(input->raw);
   xfree(input);
 }
 
@@ -158,19 +175,8 @@ Input_do_fft(Input_t *input)
       input->out[c][k] /= (float)input->size;
       /*  printf("(%d %d %f) ", c, k, input->out[c][k]); */
     }
-#if 0
-
-    input->spectrum[c][0] = input->out[c][0] * input->out[c][0];  /* DC component */
-
-    for (k = 1; k < input->spectrum_size; ++k)  /* (k < N/2 rounded up) */
-      input->spectrum[c][k] = input->out[c][k] * input->out[c][k] + input->out[c][N-k] * input->out[c][N-k];
-    
-    if (even) /* N is even */
-      input->spectrum[c][input->spectrum_size-1] = input->out[c][input->spectrum_size-1] * input->out[c][input->spectrum_size-1];  /* Nyquist freq. */
-#else
     for (k = 0; k < input->spectrum_size; k++)
       input->spectrum[c][k] = input->out[c][k];
-#endif
   }
 
   for (c = 0; c < 3; c++) {
@@ -238,7 +244,7 @@ Input_set(Input_t *input, u_char mode)
     }
   else {
     assert(mode == A_STEREO);
-    for (i = 0, j = 0; i < input->size; i ++, j++) {
+    for (i = 0, j = 0; i < input->size; i++, j++) {
       /* clamp values */
       input->data[A_LEFT][i] = Input_clamp(input->data[A_LEFT][i]);
       input->data[A_RIGHT][i] = Input_clamp(input->data[A_RIGHT][i]);
@@ -255,6 +261,18 @@ Input_set(Input_t *input, u_char mode)
 
   Input_do_fft(input);
 
+  if (NULL != input->raw) { /* Write to pipe */
+    ssize_t ret, len;
+
+    for (i = 0, j = 0; i < input->size; i++) {
+      input->raw[j++] = input->data[A_LEFT][i] * INT16_MAX;
+      input->raw[j++] = input->data[A_RIGHT][i] * INT16_MAX;
+    }
+    len = 2*input->size*sizeof(int16_t);
+    ret = write(input->pipe, (const void *)input->raw, len);
+    if (ret != len)
+      xerror("Audio pipe: short write (%d of %d)\n", ret, len);
+  }
   pthread_mutex_unlock(&input->mutex);
 }
 
