@@ -42,6 +42,10 @@ typedef struct Input_s {
   /* you can also mute the input  */
   u_char  mute;
 
+  /* raw input data (usually something like s16le stereo */
+  int16_t *raw;
+  int pipe;
+
   /* Write raw input data here then call Input_set(...) */
   /* the input data, [-1..1] */
   double *data[3];
