@@ -34,8 +34,12 @@ enum RandomMode random_mode = BR_SCHEMES;
 enum OSDMode osd_mode = OSD_NONE;
 char *pid_file = NULL;
 char *themes = NULL;
+#ifdef WITH_WEBCAM
 int hflip = 1;
 int vflip = 1;
+int webcams = 1;
+char *video_base = NULL;
+#endif
 
 #define _BANNER "\n"					\
   "      _          ___ _      _          \n"		\
