@@ -110,17 +110,13 @@ Params3d_init(Params3d_t *p)
   p->auto_rotate[Y_AXIS] = 1;
   p->rotate_amount[Y_AXIS] = 3 * ROT_STEP;
 
-#ifdef Z_BUFFER
-  Params3d_init_z_buffer();
-#endif
-
   p->do_auto_rotate = 0;
   p->rotate_amount[X_AXIS] = 1 * ROT_STEP;
   p->rotate_amount[Y_AXIS] = 2 * ROT_STEP;
   p->rotate_amount[Z_AXIS] = 4 * ROT_STEP;
 
 #ifdef WITH_GL
-  p->gl_fov = 50;
+  p->gl_fov = 45; /* FIXME empirical value */
 #endif
 }
 
@@ -251,17 +247,17 @@ Params3d_rotate_GL(Params3d_t *p)
 
   // printf ("dx= %f, dy= %f\n", dx, dy);
 	
-  p->gl_rotations[Y_AXIS] += dx*15;
-  p->gl_rotations[X_AXIS] += dy*15;
+  p->gl_rotations[Y_AXIS] += dx*30;
+  p->gl_rotations[X_AXIS] += dy*30;
 	
   if (p->gl_rotations[Y_AXIS] > 360)
     p->gl_rotations[Y_AXIS] -= 360;
-  else if (p->gl_rotations[Y_AXIS] < -360)
+  else if (p->gl_rotations[Y_AXIS] < 0)
     p->gl_rotations[Y_AXIS] += 360;
 	
   if (p->rotations[X_AXIS] > 360)
     p->rotations[X_AXIS] -= 360;
-  else if (p->rotations[X_AXIS] < -360)
+  else if (p->rotations[X_AXIS] < 0)
     p->rotations[X_AXIS] += 360;
 	
   p->gl_xs = p->gl_xe;
@@ -284,19 +280,6 @@ Params3d_change_rotations(Params3d_t *p)
 }
 
 
-#ifdef Z_BUFFER
-void
-Params3d_init_z_buffer()
-{
-  int i, j;
-  
-  for (j = 0; j < HEIGHT; j++)
-    for (i = 0; i < WIDTH; i++)
-      z_buffer[j][i] = -1e6;
-}
-#endif
-
-
 void
 update_x(Params3d_t *p)
 {
