@@ -23,12 +23,6 @@
 #include "point3d.h"
 #include "buffer_8bits.h"
 
-/* #define Z_BUFFER */
-
-#ifdef Z_BUFFER
-static float z_buffer[HEIGHT][WIDTH];
-#endif
-
 #define ROT_STEP 0.0025         /* for 3D auto_rotations */
 
 enum Axes { X_AXIS, Y_AXIS, Z_AXIS };
@@ -179,14 +173,7 @@ set_pixel_3d_nc(const Params3d_t *params3d, Buffer8_t *b, const Point3d_t *p, co
   /*  if ((a.x >= MINX) && (a.x < WIDTH)
       && (a.y >= MINY) && (a.y < HEIGHT)) */
   if (((unsigned)(a.x-MINX) < (WIDTH-MINX)) && ((unsigned)(a.y-MINY) < (HEIGHT-MINY)))
-#ifdef Z_BUFFER
-    if (p->pos.z >= z_buffer[(int)(a.y)][(int)(a.x)]) {
-      z_buffer[(int)(a.y)][(int)(a.x)] = p->pos.z;
-      set_pixel_nc(b, (short)a.x, (short)a.y, color);
-    }
-#else
-  set_pixel_nc(b, (short)a.x, (short)a.y, color);
-#endif
+    set_pixel_nc(b, (short)a.x, (short)a.y, color);
 }
 
 
@@ -202,14 +189,7 @@ set_pixel_3d(const Params3d_t *params3d, Buffer8_t *b, const Point3d_t *p, const
   /*  if ((a.x >= MINX) && (a.x < WIDTH)
       && (a.y >= MINY) && (a.y < HEIGHT)) */
   if (((unsigned)(a.x-MINX) < (WIDTH-MINX)) && ((unsigned)(a.y-MINY) < (HEIGHT-MINY)))
-#ifdef Z_BUFFER
-    if (p->pos.z >= z_buffer[(int)(a.y)][(int)(a.x)]) {
-      z_buffer[(int)(a.y)][(int)(a.x)] = p->pos.z;
-      set_pixel_nc(b, a.x, a.y, color);
-    }
-#else
-  set_pixel_nc(b, (short)a.x, (short)a.y, color);
-#endif
+    set_pixel_nc(b, (short)a.x, (short)a.y, color);
 }
 
 
@@ -222,8 +202,4 @@ void Params3d_rotate(Params3d_t *);
 void Params3d_rotate_GL(Params3d_t *);
 void Params3d_change_rotations(Params3d_t *);
 
-#ifdef Z_BUFFER
-void Params3d_init_z_buffer();
-#endif
-
 #endif /* __BINIOU_PARAMS3D_H */
