@@ -17,6 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libavutil/mem.h>
 #include "picture_8bits.h"
 #include "pnglite.h"
 
@@ -67,7 +68,7 @@ PNG_to_Y(const png_t *png, const u_char *src)
   size_t size, i;
 
   size = png->width * png->height;
-  res = xmalloc(size*sizeof(Pixel_t));
+  res = av_malloc(size*sizeof(Pixel_t));
   dst = res;
 
   switch (png->color_type) {
@@ -145,7 +146,7 @@ Picture8_load_PNG(Picture8_t *pic, const char *filename)
 
       if ((png.width != WIDTH) || (png.height != HEIGHT)) {
 	gray_scale(dst, png.width, png.height, y);
-	xfree(y);
+	av_free(y);
       } else {
 	xfree(pic->buff->buffer);
 	pic->buff->buffer = y;
