@@ -39,7 +39,7 @@
 #endif
 
 
-static void
+static Plugin_t *
 Plugin_load(Plugin_t *p)
 {
   const char *error = NULL;
@@ -51,8 +51,13 @@ Plugin_load(Plugin_t *p)
 	
   if (p->handle == NULL) {
     error = dlerror();
-    xerror("Failed to load plugin '%s': %s\n",
-	   p->name, error);
+    fprintf(stderr, "[!] Failed to load plugin '%s': %s\n",
+	    p->name, error);
+    xfree(p->name);
+    xfree(p->file);
+    xfree(p);
+
+    return NULL;
   } else {
     if (libbiniou_verbose)
       printf("[p] Loading plugin '%s'", p->name);
@@ -113,6 +118,8 @@ Plugin_load(Plugin_t *p)
   /* Input plugin stuff (? mainly -to check --oliv3) */
   p->jthread = (void *(*)(void *)) dlsym(p->handle, "jthread");
   B_GOTSYM(p->jthread, "jthread");
+
+  return p;
 }
 
 
@@ -164,9 +171,7 @@ Plugin_new(const char *directory, const char *name, const enum PluginType type)
   else if (type == PL_OUTPUT)
     p->file = g_strdup_printf("%s/output/%s/%s.so", directory, name, name);
 
-  Plugin_load(p);
-
-  return p;
+  return Plugin_load(p);
 }
 
 
