@@ -175,30 +175,33 @@ Plugins_load(Plugins_t *ps)
 
     /* load the plugin */
     p = ps->plugins[i] = Plugin_new(ps->path, name, PL_MAIN);
-    if (libbiniou_verbose) {
-      if (NULL != p->desc)
-	printf("        %s\n", p->desc);
-      else
-	printf("!!! FIXME: %s has no description\n", name);
-    }
-
-    for (j = 0; j < i; j++)
-      if (p->id == ps->plugins[j]->id)
-	xerror("Duplicated plugin id: %li\n", p->id);
-
-    /* plugin types stuff */
-    for (t = 0; t < MAX_TYPES; t++)
-      if (*p->options & (1 << t)) {
-#ifdef XDEBUG
-	printf("[T] Has type %s\n", pTypes[t].name);
-#endif
-	if (!(*p->options & BEQ_NORANDOM))
-	  pTypes[t].count++;
+    if (NULL != p) {
+      if (libbiniou_verbose) {
+	if (NULL != p->desc)
+	  printf("        %s\n", p->desc);
+	else
+	  printf("!!! FIXME: %s has no description\n", name);
       }
+
+      for (j = 0; j < i; j++)
+	if (p->id == ps->plugins[j]->id)
+	  xerror("Duplicated plugin id: %li\n", p->id);
+
+      /* plugin types stuff */
+      for (t = 0; t < MAX_TYPES; t++)
+	if (*p->options & (1 << t)) {
 #ifdef XDEBUG
-    printf("\n");
+	  printf("[T] Has type %s\n", pTypes[t].name);
 #endif
-    i++;
+	  if (!(*p->options & BEQ_NORANDOM))
+	    pTypes[t].count++;
+	}
+#ifdef XDEBUG
+      printf("\n");
+#endif
+      i++;
+    } else
+      ps->size--;
   }
   closedir(da_dir);
 
