@@ -24,15 +24,15 @@
 
 
 /*!
- * \struct _rgba_t
- * \brief RGBA color, as four unsigned char
+ * \struct RGBA_t
+ * \brief RGBA color, as four uint8_t
  */
 typedef struct _rgba_s {
-  u_char r;
-  u_char g;
-  u_char b;
-  u_char a;
-} _rgba_t;
+  uint8_t r;
+  uint8_t g;
+  uint8_t b;
+  uint8_t a;
+} RGBA_t;
 
 
 /*!
@@ -40,8 +40,8 @@ typedef struct _rgba_s {
  * \brief RGBA color as a union
  */
 typedef union _rgba_u {
-  _rgba_t col;
-  u_char  rgbav[4];
+  RGBA_t  col;
+  uint8_t rgbav[4];
 } rgba_t;
 
 #endif /* __BINIOU_RGBA_H */
