@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -36,6 +36,9 @@ Schemes_random(Context_t *ctx)
 
   do {
     int i;
+    struct timeval t;
+
+    gettimeofday(&t, NULL);
 
     ok = 1;
     if ((schemes->shuffler != NULL) && !Shuffler_ok(schemes->shuffler)) {
@@ -43,7 +46,7 @@ Schemes_random(Context_t *ctx)
       return;
     }
 	  
-    Sequence_clear(new);
+    Sequence_clear(new, t.tv_sec);
 	  
     random = (schemes->shuffler != NULL) ? Shuffler_get(schemes->shuffler) : 0;
     for (i = 0; ok && schemes->schemes[random][i].type; i++) {
