@@ -153,11 +153,11 @@ Sequence_load(const char *file)
       goto error;
     } else {
       s->picture_id = Pictures_find(picture);
-      if (s->picture_id == -1) {
+      if (s->picture_id == 0) {
 	if (libbiniou_verbose)
 	  printf("[!] Picture '%s' not found, using default\n", picture);
-	xfree(picture);
       }
+      xfree(picture);
     }
   } else {
     if (pictures == NULL) {
