@@ -17,6 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <inttypes.h>
 #include "globals.h"
 #include "xmlutils.h"
 #include "sequence.h"
@@ -115,8 +116,8 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
 
   if (s->name != NULL)
     xfree(s->name);
-  s->name = g_strdup_printf("%lu", s->id);
-  printf("[s] Saving sequence %lu\n", s->id);
+  s->name = g_strdup_printf("%"PRIu32, s->id);
+  printf("[s] Saving sequence %"PRIu32"\n", s->id);
 
   home_dir = g_get_home_dir();
   blah = g_strdup_printf("%s/%s", home_dir, SAVEDIR);
@@ -126,7 +127,7 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
   if (overwrite)
     filename = g_strdup_printf("%s/%s/%s.xml", home_dir, SAVEDIR, s->name);
   else
-    filename = g_strdup_printf("%s/%s/%lu.xml", home_dir, SAVEDIR, s->id);
+    filename = g_strdup_printf("%s/%s/%"PRIu32".xml", home_dir, SAVEDIR, s->id);
 
   printf("[s] Filename: %s\n", filename);
 
