@@ -33,8 +33,6 @@ SequenceManager_new()
   sm->next = Sequence_new(0);
   sm->transient = Sequence_new(0);
 
-  SequenceManager_load_banks(sm);
-
   return sm;
 }
 
@@ -49,7 +47,7 @@ SequenceManager_delete(SequenceManager_t *sm)
 }
 
 
-const int
+int
 SequenceManager_is_transient(const SequenceManager_t *sm, const Sequence_t *s)
 {
   return (sm->transient == s);
