@@ -82,24 +82,6 @@ SequenceManager_event(SequenceManager_t *sm, const Event_t *e)
     }
     break;
 
-  case BC_STORE_BANK:
-    printf("[i] Storing sequence id %li in bank #%d\n", sm->cur->id, (e->arg0+1));
-    SequenceManager_store_bank(sm, e->arg0);
-    return 1;
-    break;
-
-  case BC_USE_BANKSET:
-    printf("[i] Using bankset %d\n", (e->arg0+1));
-    SequenceManager_use_bankset(sm, e->arg0);
-    return 1;
-    break;
-
-  case BC_SAVE_BANKS:
-    printf("[i] Writing banks file\n");
-    SequenceManager_save_banks(sm);
-    return 1;
-    break;
-
   default:
     break;
   }
