@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -61,6 +61,8 @@ Shuffler_verbose(Shuffler_t *s)
 }
 
 
+extern u_char libbiniou_verbose;
+
 static void
 Shuffler_display(const Shuffler_t *s)
 {
@@ -70,7 +72,10 @@ Shuffler_display(const Shuffler_t *s)
   assert(s != NULL);
   if (!s->size)
     return;
-  
+
+  if (!libbiniou_verbose)
+    return;
+
   printf("[S] Shuffler(%d): Available= [", s->size);
   for (c = 0; c < s->size; c++) {
     if (!s->used[c] && !s->disabled[c]) {
