@@ -26,49 +26,54 @@
 #endif
 
 #ifndef CAPTURE_SET
-#define CAP_WIDTH  640
-#define CAP_HEIGHT 480
+#define CAP_WIDTH  320
+#define CAP_HEIGHT 240
 #endif /* CAPTURE_SET */
 
 #define CLEAR(x) memset(&(x), 0, sizeof(x))
 
 typedef enum {
   IO_METHOD_READ,
-  IO_METHOD_MMAP,
-  IO_METHOD_USERPTR,
+  IO_METHOD_MMAP
 } io_method;
 
-struct buffer {
-  void *start;
+typedef struct buffer {
+  void   *start;
   size_t length;
-};
+} buffer_t;
 
 
-#define DEFAULT_VIDEO_DEVICE "/dev/video0"
+#define DEFAULT_VIDEO_DEVICE "/dev/video"
+#define WEBCAM_MMAP 4
 
-/* options */
-char *dev_name;
-
-int fd;
-io_method io;
-unsigned int n_buffers;
-struct buffer *buffers;
-
-pthread_t thr;
+typedef struct {
+  int       cam_no;
+  Context_t *ctx;
+  io_method io;
+  int       fd;
+  int       n_buffers;
+  buffer_t  *buffers;
+  int       hflip;
+  int       vflip;
+} webcam_t;
 
 void parse_options();
 
-int  open_device();
-int  init_device();
-void enumerate_cids();
-void start_capturing();
+int  open_device(webcam_t *, const uint8_t);
+int  init_device(webcam_t *);
+void enumerate_cids(webcam_t *);
+void start_capturing(webcam_t *);
+int  list_inputs(const webcam_t *);
 
 void* loop(void *);
 
-void stop_capturing();
-void uninit_device();
-void close_device();
+void stop_capturing(webcam_t *);
+void uninit_device(webcam_t *);
+void close_device(const webcam_t *);
 
 int xioctl(int, int, void *);
 
+void cam_hflip(int, const int);
+void cam_vflip(int, const int);
+
 #endif /* __WEBCAM_H */
