@@ -20,7 +20,8 @@
 #include "webcam.h"
 
 
-io_method io = IO_METHOD_MMAP;
+extern char *video_base;
+
 
 int
 xioctl(int fd, int request, void *arg)
@@ -36,145 +37,96 @@ xioctl(int fd, int request, void *arg)
 
 
 void
-init_read(unsigned int buffer_size)
+init_read(unsigned int buffer_size, webcam_t *cam)
 {
-  buffers = calloc(1, sizeof(*buffers));
-
-  if (!buffers)
-    xerror("Out of memory\n");
-
-  buffers[0].length = buffer_size;
-  buffers[0].start = malloc(buffer_size);
-
-  if (!buffers[0].start)
-    xerror("Out of memory\n");
+  cam->buffers = xmalloc(sizeof(buffer_t));
+  cam->buffers[0].length = buffer_size;
+  cam->buffers[0].start = xmalloc(buffer_size);
 }
 
 
 void
-init_mmap()
+init_mmap(webcam_t *cam)
 {
   struct v4l2_requestbuffers req;
 
   CLEAR(req);
 
-  req.count               = 4;
+  req.count               = WEBCAM_MMAP;
   req.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
   req.memory              = V4L2_MEMORY_MMAP;
 
-  if (-1 == xioctl(fd, VIDIOC_REQBUFS, &req)) {
+  if (-1 == xioctl(cam->fd, VIDIOC_REQBUFS, &req)) {
     if (EINVAL == errno)
-      xerror("%s does not support memory mapping\n", dev_name);
+      xerror("%s%d does not support memory mapping\n", video_base, cam->cam_no);
     else
       xperror("VIDIOC_REQBUFS");
   }
 
   if (req.count < 2)
-    xerror("Insufficient buffer memory on %s\n", dev_name);
+    xerror("Insufficient buffer memory on %s%d\n", video_base, cam->cam_no);
 
-  buffers = calloc(req.count, sizeof(*buffers));
+  cam->buffers = xmalloc(req.count*sizeof(buffer_t));
 
-  if (!buffers)
-    xerror("Out of memory\n");
+  for (cam->n_buffers = 0; cam->n_buffers < (int)req.count; ++cam->n_buffers) {
+   struct v4l2_buffer buf;
 
-  for (n_buffers = 0; n_buffers < req.count; ++n_buffers) {
-    struct v4l2_buffer buf;
+   CLEAR(buf);
 
-    CLEAR(buf);
+   buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+   buf.memory      = V4L2_MEMORY_MMAP;
+   buf.index       = cam->n_buffers;
 
-    buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-    buf.memory      = V4L2_MEMORY_MMAP;
-    buf.index       = n_buffers;
+   if (-1 == xioctl(cam->fd, VIDIOC_QUERYBUF, &buf))
+     xperror("VIDIOC_QUERYBUF");
 
-    if (-1 == xioctl(fd, VIDIOC_QUERYBUF, &buf))
-      xperror("VIDIOC_QUERYBUF");
+   cam->buffers[cam->n_buffers].length = buf.length;
+   cam->buffers[cam->n_buffers].start =
+     mmap(NULL /* start anywhere */,
+	  buf.length,
+	  PROT_READ | PROT_WRITE /* required */,
+	  MAP_SHARED /* recommended */,
+	  cam->fd, buf.m.offset);
 
-    buffers[n_buffers].length = buf.length;
-    buffers[n_buffers].start =
-      mmap(NULL /* start anywhere */,
-	   buf.length,
-	   PROT_READ | PROT_WRITE /* required */,
-	   MAP_SHARED /* recommended */,
-	   fd, buf.m.offset);
-
-    if (MAP_FAILED == buffers[n_buffers].start)
-      xperror("mmap");
-  }
-}
-
-
-void
-init_userp(unsigned int buffer_size)
-{
-  struct v4l2_requestbuffers req;
-  unsigned int page_size;
-
-  page_size = getpagesize();
-  buffer_size = (buffer_size + page_size - 1) & ~(page_size - 1);
-
-  CLEAR(req);
-
-  req.count               = 4;
-  req.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-  req.memory              = V4L2_MEMORY_USERPTR;
-
-  if (-1 == xioctl(fd, VIDIOC_REQBUFS, &req)) {
-    if (EINVAL == errno)
-      xerror("%s does not support user pointer i/o\n", dev_name);
-    else
-      xperror("VIDIOC_REQBUFS");
-  }
-
-  buffers = calloc(4, sizeof(*buffers));
-
-  if (!buffers)
-    xerror("Out of memory\n");
-
-  for (n_buffers = 0; n_buffers < 4; ++n_buffers) {
-    buffers[n_buffers].length = buffer_size;
-    buffers[n_buffers].start = memalign(/* boundary */ page_size,
-					buffer_size);
-
-    if (!buffers[n_buffers].start)
-      xerror("Out of memory\n");
+   if (MAP_FAILED == cam->buffers[cam->n_buffers].start)
+     xperror("mmap");
   }
 }
 
 
 int
-init_device()
+init_device(webcam_t *cam)
 {
   struct v4l2_capability cap;
   struct v4l2_cropcap cropcap;
   struct v4l2_crop crop;
   struct v4l2_format fmt;
-  unsigned int min;
+  //  unsigned int min;
 
-  if (-1 == xioctl(fd, VIDIOC_QUERYCAP, &cap)) {
+  if (-1 == xioctl(cam->fd, VIDIOC_QUERYCAP, &cap)) {
     if (EINVAL == errno) {
-      printf("[!] %s is no V4L2 device\n", dev_name);
+      printf("[!] %s%d is no V4L2 device\n", video_base, cam->cam_no);
       return -1;
     } else
       xperror("VIDIOC_QUERYCAP");
   }
 
   if (!(cap.capabilities & V4L2_CAP_VIDEO_CAPTURE)) {
-    printf("[!] %s is no video capture device\n", dev_name);
+    printf("[!] %s%d is no video capture device\n", video_base, cam->cam_no);
     return -1;
   }
   
-  switch (io) {
+  switch (cam->io) {
   case IO_METHOD_READ:
     if (!(cap.capabilities & V4L2_CAP_READWRITE)) {
-      printf("[!] %s does not support read i/o\n", dev_name);
+      printf("[!] %s%d does not support read i/o\n", video_base, cam->cam_no);
       return -1;
     }
     break;
 
   case IO_METHOD_MMAP:
-  case IO_METHOD_USERPTR:
     if (!(cap.capabilities & V4L2_CAP_STREAMING)) {
-      printf("[!] %s does not support streaming i/o\n", dev_name);
+      printf("[!] %s%d does not support streaming i/o\n", video_base, cam->cam_no);
       return -1;
     }
     break;
@@ -186,11 +138,14 @@ init_device()
 
   cropcap.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 
-  if (0 == xioctl(fd, VIDIOC_CROPCAP, &cropcap)) {
+  if (0 == xioctl(cam->fd, VIDIOC_CROPCAP, &cropcap)) {
     crop.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-    crop.c = cropcap.defrect; /* reset to default */
+    crop.c.width = CAP_WIDTH;
+    crop.c.height = CAP_HEIGHT;
+    crop.c.left = 0;
+    crop.c.top = 0;
 
-    if (-1 == xioctl(fd, VIDIOC_S_CROP, &crop)) {
+    if (-1 == xioctl(cam->fd, VIDIOC_S_CROP, &crop)) {
       switch (errno) {
       case EINVAL:
 	/* Cropping not supported. */
@@ -210,14 +165,16 @@ init_device()
   fmt.type                = V4L2_BUF_TYPE_VIDEO_CAPTURE;
   fmt.fmt.pix.width       = CAP_WIDTH;
   fmt.fmt.pix.height      = CAP_HEIGHT;
+  fmt.fmt.win.w.width       = CAP_WIDTH;
+  fmt.fmt.win.w.height      = CAP_HEIGHT;
   fmt.fmt.pix.pixelformat = V4L2_PIX_FMT_YUYV;
   fmt.fmt.pix.field       = V4L2_FIELD_INTERLACED;
 
-  if (-1 == xioctl(fd, VIDIOC_S_FMT, &fmt))
+  /* Note VIDIOC_S_FMT may change width and height. */
+  if (-1 == xioctl(cam->fd, VIDIOC_S_FMT, &fmt))
     return -1;
 
-  /* Note VIDIOC_S_FMT may change width and height. */
-
+#if 0
   /* Buggy driver paranoia. */
   min = fmt.fmt.pix.width * 2;
   if (fmt.fmt.pix.bytesperline < min)
@@ -225,46 +182,39 @@ init_device()
   min = fmt.fmt.pix.bytesperline * fmt.fmt.pix.height;
   if (fmt.fmt.pix.sizeimage < min)
     fmt.fmt.pix.sizeimage = min;
+#endif
 
-  switch (io) {
+  switch (cam->io) {
   case IO_METHOD_READ:
-    init_read(fmt.fmt.pix.sizeimage);
+    init_read(fmt.fmt.pix.sizeimage, cam);
     break;
 
   case IO_METHOD_MMAP:
-    init_mmap();
-    break;
-
-  case IO_METHOD_USERPTR:
-    init_userp(fmt.fmt.pix.sizeimage);
+    init_mmap(cam);
     break;
   }
+#ifdef DEBUG
+  printf("[i] Webcam %d initialized\n", cam->cam_no);
+#endif
 
   return 0;
 }
 
 
 void
-uninit_device()
+uninit_device(webcam_t *cam)
 {
-  unsigned int i;
+  int i;
 
-  switch (io) {
+  switch (cam->io) {
   case IO_METHOD_READ:
-    free(buffers[0].start);
+    free(cam->buffers[0].start);
     break;
 
   case IO_METHOD_MMAP:
-    for (i = 0; i < n_buffers; ++i)
-      if (-1 == munmap (buffers[i].start, buffers[i].length))
+    for (i = 0; i < cam->n_buffers; ++i)
+      if (-1 == munmap(cam->buffers[i].start, cam->buffers[i].length))
 	xperror("munmap");
     break;
-
-  case IO_METHOD_USERPTR:
-    for (i = 0; i < n_buffers; ++i)
-      free(buffers[i].start);
-    break;
   }
-
-  free(buffers);
 }
