@@ -23,7 +23,7 @@ extern int hflip, vflip;
 
 
 static void
-process_image(Context_t *ctx, void *p)
+process_image(webcam_t *webcam, void *p)
 {
   int i, j;
   u_char *q = p;
@@ -32,18 +32,21 @@ process_image(Context_t *ctx, void *p)
   Pixel_t temp[CAP_WIDTH*CAP_HEIGHT];
   Buffer8_t *save;
 
-  dst = ctx->buffers[CAM_IN_BUFFER];
-  d = (Pixel_t *)&temp;
+  p++;
+#if 1
+  d = temp;
 
+  /* TODO: use sws_scale/colorspace */
   /* XXX lame YUYV -> Y conversion */
   for (j = 0; j < CAP_HEIGHT; j++)
     for (i = 0; i < CAP_WIDTH; i++) {
       *d++ = *q;
       q += 2;
     }
+#endif
 
-  save = Buffer8_clone(dst);
-  pthread_mutex_lock(&ctx->cam_mtx);
+  pthread_mutex_lock(&webcam->ctx->cam_mtx[webcam->cam_no]);
+  dst = webcam->ctx->cam_save[webcam->cam_no][0];
 
   if ((WIDTH == CAP_WIDTH) && (HEIGHT == CAP_HEIGHT))
     memcpy(dst->buffer, temp, BUFFSIZE*sizeof(Pixel_t));
@@ -56,20 +59,22 @@ process_image(Context_t *ctx, void *p)
   if (vflip)
     Buffer8_flip_v(dst);
 
-  Context_push_webcam(ctx, save);
-  pthread_mutex_unlock(&ctx->cam_mtx);
+  save = Buffer8_clone(dst); /* TODO s/save/new_picture */
+  Context_push_webcam(webcam->ctx, save, webcam->cam_no);
+  pthread_mutex_unlock(&webcam->ctx->cam_mtx[webcam->cam_no]);
 }
 
 
 static int
-read_frame(Context_t *ctx)
+read_frame(webcam_t *cam)
 {
   struct v4l2_buffer buf;
-  unsigned int i;
 
-  switch (io) {
+  switch (cam->io) {
   case IO_METHOD_READ:
-    if (-1 == read(fd, buffers[0].start, buffers[0].length)) {
+    if (-1 == read(cam->fd,
+		   cam->buffers[0].start,
+		   cam->buffers[0].length)) {
       switch (errno) {
       case EAGAIN:
 	return 0;
@@ -83,8 +88,7 @@ read_frame(Context_t *ctx)
 	xperror("read");
       }
     }
-
-    process_image(ctx, buffers[0].start);
+    process_image(cam, cam->buffers[0].start);
 
     break;
 
@@ -94,7 +98,7 @@ read_frame(Context_t *ctx)
     buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
     buf.memory = V4L2_MEMORY_MMAP;
 
-    if (-1 == xioctl(fd, VIDIOC_DQBUF, &buf)) {
+    if (-1 == xioctl(cam->fd, VIDIOC_DQBUF, &buf)) {
       switch (errno) {
       case EAGAIN:
 	return 0;
@@ -109,49 +113,15 @@ read_frame(Context_t *ctx)
       }
     }
 
-    assert(buf.index < n_buffers);
+    assert((int)buf.index < cam->n_buffers);
 
-    process_image(ctx, buffers[buf.index].start);
-
-    if (-1 == xioctl(fd, VIDIOC_QBUF, &buf))
+    // printf("index %d, process_image(%d) bytes\n", buf.index, (int)cam->buffers[buf.index].length);
+    process_image(cam, cam->buffers[buf.index].start);
+    // printf("process_image done cam #%d\n", cam->cam_no);
+    if (-1 == xioctl(cam->fd, VIDIOC_QBUF, &buf))
       xperror("VIDIOC_QBUF");
 
     break;
-
-  case IO_METHOD_USERPTR:
-    CLEAR(buf);
-
-    buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-    buf.memory = V4L2_MEMORY_USERPTR;
-
-    if (-1 == xioctl(fd, VIDIOC_DQBUF, &buf)) {
-      switch (errno) {
-      case EAGAIN:
-	return 0;
-
-      case EIO:
-	/* Could ignore EIO, see spec. */
-
-	/* fall through */
-
-      default:
-	xperror("BBB VIDIOC_DQBUF");
-      }
-    }
-
-    for (i = 0; i < n_buffers; ++i)
-      if (buf.m.userptr == (unsigned long)buffers[i].start
-	  && buf.length == buffers[i].length)
-	break;
-
-    assert(i < n_buffers);
-
-    process_image(ctx, (void *)buf.m.userptr);
-
-    if (-1 == xioctl(fd, VIDIOC_QBUF, &buf))
-      xperror("CCC VIDIOC_QBUF");
-
-    break;
   }
 
   return 1;
@@ -161,21 +131,21 @@ read_frame(Context_t *ctx)
 void *
 loop(void *args)
 {
-  Context_t *ctx = (Context_t *)args;
+  webcam_t *webcam = (webcam_t *)args;
 
-  while (ctx->running) {
+  while (webcam->ctx->running) {
     fd_set fds;
     struct timeval tv;
     int r;
 
     FD_ZERO(&fds);
-    FD_SET(fd, &fds);
+    FD_SET(webcam->fd, &fds);
 
     /* Timeout. */
     tv.tv_sec = 30;
     tv.tv_usec = 0;
 
-    r = select(fd + 1, &fds, NULL, NULL, &tv);
+    r = select(webcam->fd + 1, &fds, NULL, NULL, &tv);
 
     if (-1 == r) {
       if (EINTR == errno)
@@ -187,11 +157,11 @@ loop(void *args)
     if (0 == r)
       xerror("select timeout\n");
 
-    read_frame(ctx);
+    read_frame(webcam);
 
-    if (!ctx->ref_taken) {
-      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->buffers[CAM_REF_BUFFER]);
-      ctx->ref_taken = 1;
+    if (!webcam->ctx->ref_taken[webcam->cam_no]) {
+      Buffer8_copy(webcam->ctx->cam_save[webcam->cam_no][0], webcam->ctx->cam_ref[webcam->cam_no]);
+      webcam->ctx->ref_taken[webcam->cam_no] = 1;
     }
   }
 
