@@ -21,42 +21,55 @@
 
 
 extern u_long options;
+extern char *video_base;
 
 
 int
-open_device()
+open_device(webcam_t *cam, const uint8_t try)
 {
   struct stat st;
+  gchar *dev_name = NULL;
+  int base_len = strlen(video_base);
+
+  /* remove trailing digits: "/dev/video000" => "/dev/video" */
+  while ((base_len > 1) && isdigit(video_base[base_len-1])) {
+    video_base[base_len-1] = '\0';
+    base_len--;
+  }
+  dev_name = g_strdup_printf("%s%d", video_base, cam->cam_no+try);
 
   if (-1 == stat(dev_name, &st)) {
     printf("[!] Cannot identify '%s': %d, %s\n",
 	   dev_name, errno, strerror(errno));
+    g_free(dev_name);
     return -1;
   }
 
   if (!S_ISCHR(st.st_mode)) {
     printf("[!] %s is no device\n", dev_name);
+    g_free(dev_name);
     return -1;
   }
 
-  fd = open(dev_name, O_RDWR /* required */ | O_NONBLOCK, 0);
+  cam->fd = open(dev_name, O_RDWR /* required */ | O_NONBLOCK, 0);
 
-  if (-1 == fd) {
-    printf("[!] Cannot open '%s': %d, %s\n",
-	   dev_name, errno, strerror (errno));
+  if (-1 == cam->fd) {
+    printf("[!] Cannot open %s: %d, %s\n",
+	   dev_name, errno, strerror(errno));
+    g_free(dev_name);
     return -1;
   } else
-    printf("[i] Successfully opened %s as a video device, fd= %d\n", dev_name, fd);
+    printf("[i] Successfully opened %s as a video device, fd= %d\n", dev_name, cam->fd);
+
+  g_free(dev_name);
 
   return 0;
 }
 
 
 void
-close_device()
+close_device(const webcam_t *cam)
 {
-  if (-1 == close(fd))
+  if (-1 == close(cam->fd))
     xperror("close");
-
-  fd = -1;
 }
