@@ -19,7 +19,8 @@
 
 #include "webcam.h"
 
-extern int hflip, vflip;
+extern int hflip, vflip, webcams;
+extern char *video_base;
 
 
 static void
@@ -28,21 +29,26 @@ process_token(const char *tok)
   gchar **varval = NULL, **vv;
 
   // printf(">>>>>>>>> token: '%s' <<<<<<<<<<<<<\n", tok);
-  varval = g_strsplit(tok, "=", 0);
+  varval = g_strsplit(tok, ":", 0);
 
   vv = varval;
 
-  if (!strcmp((const char *)*vv, "device")) {
+  if (!strcmp((const char *)*vv, "webcams")) {
     vv++;
     assert(NULL != *vv);
-    printf("[i] webcam: device set to %s\n", *vv);
-    free(dev_name);
-    dev_name = strdup(*vv);
+    webcams = xatol(*vv);
+    printf("[E] webcam: grabbing %d device%s\n", webcams, (webcams == 1) ? "" : "s");
+  } if (!strcmp((const char *)*vv, "device")) {
+    vv++;
+    assert(NULL != *vv);
+    printf("[E] webcam: device set to %s\n", *vv);
+    free(video_base);
+    video_base = strdup(*vv);
   } else if (!strcmp((const char *)*vv, "hflip")) {
-    printf("[i] webcam: set horizontal flip\n");
+    printf("[E] webcam: set horizontal flip\n");
     hflip = !hflip;
   } else if (!strcmp((const char *)*vv, "vflip")) {
-    printf("[i] webcam: set vertical flip\n");
+    printf("[E] webcam: set vertical flip\n");
     vflip = !vflip;
   }
 
@@ -69,9 +75,7 @@ parse_options()
 {
   char *options = NULL;
 
-  dev_name = strdup(DEFAULT_VIDEO_DEVICE);
-
-  options = getenv("BINIOU_WEBCAM");
+  options = getenv("LEBINIOU_WEBCAM");
 
   if (NULL != options)
     process_options(options);
